#!/usr/bin/python3
"""
    GeckoLogStruct - A class to manage the LogStruct for 'InYT-V2 v64'
"""

from . import (
    GeckoByteStructAccessor,
    GeckoWordStructAccessor,
    GeckoTimeStructAccessor,
    GeckoBoolStructAccessor,
    GeckoEnumStructAccessor,
    GeckoTempStructAccessor,
)

# Constants for this class
ACMCVD = "".join(chr(c) for c in [83, 79, 117, 116, 55, 67, 117, 114])
ACQFFT = "".join(
    chr(c) for c in [82, 104, 78, 111, 70, 108, 111, 88, 84, 114, 105, 101, 115]
)
AFIKJP = 320
AIIDNI = "".join(
    chr(c)
    for c in [
        83,
        108,
        97,
        118,
        101,
        84,
        104,
        101,
        114,
        109,
        105,
        115,
        116,
        97,
        110,
        99,
        101,
        69,
        114,
        114,
    ]
)
AIVEMV = 473
AJVDQL = "".join(
    chr(c) for c in [83, 108, 97, 118, 101, 72, 116, 114, 83, 116, 117, 99, 107]
)
AKQXPI = "".join(chr(c) for c in [65, 76, 76])
AKSTSE = 327
AOAWBS = "".join(chr(c) for c in [67, 104, 101, 99, 107, 70, 108, 111])
AONPYY = 310
ATDZXN = "".join(chr(c) for c in [65, 85, 88])
AWBSIR = "".join(
    chr(c) for c in [80, 114, 111, 103, 69, 99, 111, 110, 65, 99, 116, 105, 118, 101]
)
AZMKQT = 346
BBEKBD = "".join(chr(c) for c in [67, 70, 71, 51])
BDFSRO = "".join(chr(c) for c in [67, 70, 71, 53])
BDJQRJ = "".join(chr(c) for c in [68, 74, 83, 52])
BEKBDF = 451
BFEGZU = 261
BHZVOA = 332
BIAMJM = 277
BJEUTO = "".join(chr(c) for c in [80, 97, 99, 107, 67, 111, 114, 101, 73, 68])
BJLOIN = 460
BLKXSJ = "".join(
    chr(c)
    for c in [
        82,
        101,
        109,
        111,
        116,
        101,
        67,
        111,
        110,
        102,
        105,
        103,
        73,
        110,
        100,
        101,
        120,
    ]
)
BMJVHF = 256
BQFYLJ = 384
BQNRXC = 360
BQSNQL = 284
BSIRYX = "".join(chr(c) for c in [69, 99, 111, 110, 65, 99, 116, 105, 118, 101])
BSKSOK = 258
BSSUHB = "".join(chr(c) for c in [83, 108, 97, 118, 101, 72, 76, 69, 114, 114])
BVWVUB = "".join(chr(c) for c in [80, 97, 99, 107, 66, 111, 111, 116, 82, 101, 118])
BWJYKL = 282
BXIBHZ = "".join(chr(c) for c in [83, 79, 117, 116, 49, 49])
BXTIAC = "".join(
    chr(c) for c in [82, 104, 82, 101, 103, 80, 114, 111, 98, 101, 69, 114, 114]
)
BXYBQS = "".join(chr(c) for c in [79, 84, 72, 69, 82, 95, 69, 82, 82])
BYGDSB = 289
CBFEGZ = "".join(chr(c) for c in [80, 49])
CCPQIP = "".join(
    chr(c)
    for c in [
        82,
        101,
        109,
        111,
        116,
        101,
        70,
        105,
        108,
        116,
        65,
        99,
        116,
        105,
        111,
        110,
    ]
)
CGETIX = "".join(chr(c) for c in [83, 79, 117, 116, 53, 67, 117, 114])
CHWDAF = "".join(chr(c) for c in [45, 45, 45])
CMCVDS = 341
CPQIPO = 263
CQBMJV = 317
CRHYUA = 375
CRTFMN = "".join(chr(c) for c in [51, 50, 75])
CTHBSK = "".join(chr(c) for c in [85, 100, 80, 51])
CTTGCR = "".join(
    chr(c)
    for c in [
        77,
        79,
        68,
        69,
        95,
        49,
        95,
        65,
        78,
        68,
        95,
        72,
        69,
        65,
        84,
        73,
        78,
        71,
        95,
        70,
        65,
        73,
        76,
    ]
)
CUGUCY = 479
CVDSSR = 342
CVYYPI = "".join(chr(c) for c in [68, 101, 97, 108, 101, 114, 79, 112, 116])
CWAONP = 7
CXQIEF = "".join(chr(c) for c in [81, 117, 105, 101, 116, 83, 116, 97, 116, 101])
CYWONF = 476
CZOLSI = "".join(
    chr(c)
    for c in [
        105,
        110,
        70,
        108,
        111,
        80,
        114,
        101,
        115,
        115,
        117,
        114,
        101,
        83,
        119,
        68,
        101,
        116,
        101,
        99,
        116,
        101,
        100,
    ]
)
DAFIKJ = "".join(chr(c) for c in [83, 79, 117, 116, 49])
DDPMXF = "".join(chr(c) for c in [67, 70, 71, 57])
DFSROG = 453
DGKEAK = 326
DJQRJJ = "".join(chr(c) for c in [105, 110, 67, 108, 101, 97, 114])
DKHTZB = 448
DMPSCT = 374
DNIBXT = 354
DNQGVU = "".join(chr(c) for c in [82, 101, 115, 116, 114, 105, 99, 116, 101, 100])
DPMXFU = 457
DQLAII = 351
DRXAIV = "".join(chr(c) for c in [67, 70, 71, 50, 52])
DSBDJQ = "".join(chr(c) for c in [77, 97, 115, 73, 66, 67])
DSSRUR = 343
DUBSSU = 315
DZXNQT = "".join(chr(c) for c in [83, 79, 117, 116, 50])
EAKSTS = "".join(chr(c) for c in [83, 79, 117, 116, 49, 67, 117, 114])
ECVYYP = "".join(
    chr(c) for c in [73, 110, 115, 116, 97, 108, 108, 101, 114, 79, 112, 116]
)
EEZFET = "".join(chr(c) for c in [67, 70, 71, 50, 49])
EFJTAC = "".join(
    chr(c) for c in [70, 105, 108, 116, 101, 114, 65, 99, 99, 101, 115, 115]
)
EFXQGL = "".join(chr(c) for c in [83, 79, 65, 75])
EGZUQE = "".join(chr(c) for c in [76, 79, 87])
EJNIBX = "".join(
    chr(c) for c in [67, 79, 73, 76, 95, 83, 69, 78, 83, 79, 82, 95, 69, 82, 82]
)
EKBDFS = "".join(chr(c) for c in [67, 70, 71, 52])
EKCWAO = "".join(chr(c) for c in [83, 76, 86, 95, 72, 69, 65, 84, 69, 82])
EKVKZI = "".join(chr(c) for c in [75, 105, 110, 80, 117, 109, 112, 79, 102, 102])
ELHBQN = "".join(chr(c) for c in [75, 101, 121, 112, 97, 100, 73, 68])
ELWUEU = 463
EMCGET = "".join(chr(c) for c in [83, 79, 117, 116, 52, 67, 117, 114])
EMVCYW = "".join(chr(c) for c in [67, 70, 71, 50, 55])
EOCTHB = "".join(chr(c) for c in [85, 100, 80, 50])
ETDRXA = "".join(chr(c) for c in [67, 70, 71, 50, 51])
ETIXQV = "".join(chr(c) for c in [83, 79, 117, 116, 72, 116, 114, 67, 117, 114])
EUHNNX = 465
EUTOPH = "".join(chr(c) for c in [80, 97, 99, 107, 67, 111, 114, 101, 82, 101, 118])
EXLSXU = "".join(chr(c) for c in [80, 53])
EZFETD = 469
FCRTFM = "".join(chr(c) for c in [49, 54, 75])
FEFJTA = 367
FEGZUQ = "".join(chr(c) for c in [72, 73, 71, 72])
FETDRX = 470
FFTTID = "".join(chr(c) for c in [105, 110, 84, 67, 105, 112, 68, 101, 108, 97, 121])
FIKJPU = "".join(chr(c) for c in [78, 65])
FJBIAM = 275
FJTACC = 262
FSROGM = "".join(chr(c) for c in [67, 70, 71, 54])
FTHECV = 319
FTSIFJ = "".join(chr(c) for c in [83, 119, 109, 65, 100, 99])
FTTIDU = 311
FUBJLO = 459
FXQGLR = "".join(chr(c) for c in [79, 70, 70])
FYLJUI = 378
FZCZOL = "".join(chr(c) for c in [67, 70, 71, 51, 49])
FZDGKE = 324
GCRHYU = "".join(
    chr(c) for c in [70, 111, 114, 99, 101, 67, 104, 101, 99, 107, 70, 108, 111]
)
GDSBDJ = "".join(chr(c) for c in [105, 110, 88, 69])
GETIXQ = 331
GKEAKS = "".join(chr(c) for c in [72, 84, 82])
GLRAHE = 259
GMDDPM = "".join(chr(c) for c in [67, 70, 71, 56])
GQPLSP = "".join(chr(c) for c in [77, 69, 68])
GSELHB = "".join(chr(c) for c in [73, 78, 86, 65, 76, 73, 68, 95, 84, 89, 80, 69])
GTYIYW = 296
GVUNXN = "".join(chr(c) for c in [75, 101, 121, 112, 97, 100, 84, 121, 112, 101])
GYOUSP = "".join(chr(c) for c in [80, 117, 114, 103, 101])
HBQNRX = "".join(chr(c) for c in [75, 101, 121, 112, 97, 100, 82, 101, 118])
HBSKSO = "".join(chr(c) for c in [85, 100, 80, 53])
HBVWVU = 285
HBXIBH = "".join(chr(c) for c in [83, 79, 117, 116, 49, 48])
HECVYY = "".join(chr(c) for c in [])
HEOCTH = 4
HFTHEC = "".join(chr(c) for c in [77, 101, 110, 117])
HIUSOO = "".join(chr(c) for c in [85, 100, 80, 117, 109, 112, 84, 105, 109, 101])
HNNXWE = 466
HTBJEU = "".join(chr(c) for c in [67, 69])
HTZBBE = 449
HUGTYI = 295
HUOJRJ = "".join(chr(c) for c in [85, 100, 76, 105])
HWDAFI = "".join(chr(c) for c in [82, 69, 83, 69, 84])
HXEKVK = "".join(
    chr(c)
    for c in [84, 104, 101, 114, 109, 105, 115, 116, 97, 110, 99, 101, 69, 114, 114]
)
IACQFF = 309
IAMJMA = "".join(chr(c) for c in [72, 101, 97, 116, 105, 110, 103])
IBHZVO = "".join(chr(c) for c in [83, 68, 105, 114, 101, 99, 116])
IBXTIA = "".join(chr(c) for c in [82, 104, 72, 119, 72, 76])
IBXYBQ = "".join(chr(c) for c in [80, 82, 69, 83, 83, 85, 82, 69, 95, 69, 82, 82])
ICXQIE = 1
IDNIBX = "".join(
    chr(c)
    for c in [83, 108, 97, 118, 101, 77, 105, 115, 115, 105, 110, 103, 69, 114, 114]
)
IDUBSS = "".join(
    chr(c)
    for c in [83, 108, 97, 118, 101, 75, 105, 110, 78, 111, 70, 108, 111, 69, 114, 114]
)
IEFXQG = "".join(chr(c) for c in [68, 82, 65, 73, 78])
IFJBIA = "".join(
    chr(c) for c in [82, 101, 97, 108, 83, 101, 116, 80, 111, 105, 110, 116, 71]
)
IGYOUS = 273
IHBXIB = "".join(chr(c) for c in [83, 79, 117, 116, 57])
IIDNIB = "".join(
    chr(c)
    for c in [
        83,
        108,
        97,
        118,
        101,
        65,
        109,
        98,
        105,
        97,
        110,
        116,
        79,
        72,
        76,
        101,
        118,
        101,
        108,
        50,
    ]
)
IJUGSE = "".join(chr(c) for c in [75, 56, 48, 48])
IKFWRK = "".join(chr(c) for c in [72, 69, 65, 84])
IKJPUN = "".join(chr(c) for c in [80, 49, 72])
ILXWAJ = "".join(chr(c) for c in [72, 101, 97, 116, 101, 114, 83, 116, 117, 99, 107])
INEJNI = "".join(chr(c) for c in [67, 72, 73, 76, 76, 95, 79, 78])
INELWU = 462
IPIVLA = "".join(
    chr(c)
    for c in [
        69,
        120,
        101,
        114,
        99,
        105,
        115,
        101,
        68,
        101,
        116,
        101,
        99,
        116,
        101,
        100,
        84,
        121,
        112,
        101,
    ]
)
IPMDMP = "".join(
    chr(c)
    for c in [
        105,
        110,
        70,
        108,
        111,
        82,
        97,
        116,
        105,
        111,
        77,
        97,
        120,
        105,
        109,
        117,
        109,
    ]
)
IPOUYN = "".join(chr(c) for c in [83, 84, 65, 82, 84])
IRYXBQ = 352
IUSOOQ = 303
IUXFEF = "".join(
    chr(c) for c in [68, 101, 97, 108, 101, 114, 76, 111, 99, 107, 83, 101, 101, 100]
)
IVDNQG = "".join(chr(c) for c in [80, 97, 99, 107, 76, 111, 103, 84, 114, 105, 103])
IVEMVC = "".join(chr(c) for c in [67, 70, 71, 50, 54])
IVLASS = "".join(chr(c) for c in [78, 79, 84, 95, 73, 78, 83, 84, 65, 76, 76, 69, 68])
IXQVXO = "".join(chr(c) for c in [83, 79, 117, 116, 54])
IYWSKW = "".join(chr(c) for c in [80, 97, 99, 107, 67, 111, 110, 102, 82, 101, 118])
JBIAMJ = "".join(
    chr(c) for c in [68, 105, 115, 112, 108, 97, 121, 101, 100, 84, 101, 109, 112, 71]
)
JEUTOP = 291
JHIUSO = 370
JIGYOU = "".join(chr(c) for c in [67, 108, 101, 97, 110])
JJJVYF = "".join(chr(c) for c in [105, 110, 84, 111, 117, 99, 104])
JJVYFC = "".join(chr(c) for c in [105, 110, 89, 84])
JLOINE = "".join(chr(c) for c in [67, 70, 71, 49, 51])
JMAOAW = 279
JMCBFE = "".join(chr(c) for c in [85, 100, 65, 117, 120, 84, 105, 109, 101])
JNIBXY = "".join(
    chr(c) for c in [65, 77, 66, 73, 69, 78, 84, 95, 84, 69, 77, 80, 95, 69, 82, 82]
)
JPUNRJ = "".join(chr(c) for c in [80, 50, 72])
JQRJJJ = "".join(chr(c) for c in [105, 110, 88, 77])
JRJHIU = 363
JTACCP = "".join(chr(c) for c in [73, 78, 84, 69, 82, 78, 65, 76])
JUGSEL = "".join(chr(c) for c in [75, 54, 48, 48, 72, 69])
JUIKFW = "".join(
    chr(c)
    for c in [72, 80, 67, 67, 104, 105, 108, 108, 82, 101, 113, 117, 101, 115, 116]
)
JUTYEK = 3
JVDQLA = "".join(
    chr(c)
    for c in [83, 108, 97, 118, 101, 82, 101, 108, 97, 121, 83, 116, 117, 99, 107]
)
JVHFTH = 274
JWMNZM = 272
JYKLGQ = "".join(chr(c) for c in [83, 119, 109, 65, 99, 116, 105, 118, 101])
JYMOUN = 266
JZTATD = "".join(chr(c) for c in [80, 52, 76])
KBDFSR = 452
KCWAON = "".join(chr(c) for c in [87, 97, 116, 101, 114, 102, 97, 108, 108])
KFWRKI = "".join(chr(c) for c in [67, 72, 73, 76, 76])
KHTZBB = "".join(chr(c) for c in [67, 70, 71, 49])
KINEJN = "".join(chr(c) for c in [72, 69, 65, 84, 95, 79, 78])
KJPUNR = "".join(chr(c) for c in [80, 49, 76])
KLGQPL = 313
KMLOIJ = "".join(chr(c) for c in [75, 52])
KPHUOJ = "".join(chr(c) for c in [85, 100, 76, 49, 50, 48])
KQTDKH = "".join(chr(c) for c in [83, 68, 105, 114, 101, 99, 116, 50, 67, 117, 114])
KQXPIC = "".join(
    chr(c)
    for c in [
        80,
        114,
        111,
        103,
        79,
        117,
        116,
        112,
        117,
        116,
        82,
        101,
        113,
        117,
        101,
        115,
        116,
    ]
)
KSOKPH = "".join(chr(c) for c in [85, 100, 66, 76])
KSTSEM = "".join(chr(c) for c in [83, 79, 117, 116, 50, 67, 117, 114])
KVKZIL = 283
KWIVDN = "".join(
    chr(c)
    for c in [80, 97, 99, 107, 78, 117, 109, 98, 101, 114, 79, 102, 67, 111, 110, 102]
)
KXSJWM = "".join(
    chr(c)
    for c in [82, 101, 109, 111, 116, 101, 78, 98, 79, 102, 80, 104, 97, 115, 101, 115]
)
KZILXW = "".join(chr(c) for c in [80, 49, 72, 83, 116, 117, 99, 107])
LAIIDN = "".join(
    chr(c)
    for c in [
        83,
        108,
        97,
        118,
        101,
        84,
        104,
        101,
        114,
        109,
        70,
        117,
        115,
        101,
        69,
        114,
        114,
    ]
)
LASSAK = "".join(chr(c) for c in [84, 82, 69, 65, 68, 77, 73, 76, 76])
LGQPLS = "".join(chr(c) for c in [78, 79])
LHBQNR = 358
LIUXFE = 364
LJUIKF = "".join(
    chr(c) for c in [72, 80, 67, 72, 101, 97, 116, 82, 101, 113, 117, 101, 115, 116]
)
LKXSJW = 270
LNMHXE = "".join(
    chr(c)
    for c in [
        83,
        105,
        108,
        101,
        110,
        116,
        77,
        111,
        100,
        101,
        65,
        99,
        116,
        105,
        118,
        101,
    ]
)
LOIJUG = "".join(chr(c) for c in [75, 54, 48, 48, 76, 69])
LOINEL = 461
LRAHEO = "".join(chr(c) for c in [76, 79])
LSIPMD = "".join(
    chr(c)
    for c in [
        105,
        110,
        70,
        108,
        111,
        82,
        97,
        116,
        105,
        111,
        77,
        105,
        110,
        105,
        109,
        117,
        109,
    ]
)
LSPFTS = "".join(
    chr(c) for c in [83, 108, 97, 118, 101, 83, 119, 109, 80, 117, 114, 103, 101]
)
LWUEUH = "".join(chr(c) for c in [67, 70, 71, 49, 54])
LXWAJV = "".join(chr(c) for c in [82, 101, 108, 97, 121, 83, 116, 117, 99, 107])
MAOAWB = "".join(
    chr(c)
    for c in [69, 120, 116, 80, 114, 111, 98, 101, 68, 101, 116, 101, 99, 116, 101, 100]
)
MCBFEG = 369
MCGETI = 330
MCVDSS = "".join(chr(c) for c in [83, 79, 117, 116, 56, 67, 117, 114])
MDDPMX = 456
MDMPSC = "".join(
    chr(c) for c in [105, 110, 70, 108, 111, 69, 114, 114, 111, 114, 84, 121, 112, 101]
)
MFZDGK = "".join(chr(c) for c in [83, 79, 117, 116, 53])
MHXEKV = "".join(
    chr(c) for c in [84, 104, 101, 114, 109, 70, 117, 115, 101, 69, 114, 114]
)
MJIGYO = 381
MJMAOA = "".join(
    chr(c) for c in [84, 101, 109, 112, 78, 111, 116, 86, 97, 108, 105, 100]
)
MJVHFT = "".join(
    chr(c) for c in [83, 116, 105, 99, 107, 68, 101, 116, 101, 99, 116, 101, 100]
)
MKQTDK = 347
MLOIJU = "".join(chr(c) for c in [75, 53])
MNHTBJ = "".join(chr(c) for c in [80, 97, 99, 107, 82, 101, 103, 105, 111, 110])
MNZMJI = "".join(
    chr(c)
    for c in [
        82,
        101,
        109,
        111,
        116,
        101,
        80,
        114,
        111,
        103,
        79,
        117,
        116,
        112,
        117,
        116,
        65,
        99,
        116,
        105,
        111,
        110,
    ]
)
MOUNBL = "".join(
    chr(c)
    for c in [82, 101, 109, 111, 116, 101, 69, 99, 111, 110, 65, 99, 116, 105, 111, 110]
)
MPSCTT = "".join(chr(c) for c in [70, 76, 79, 87, 95, 79, 75])
MVCYWO = 475
MXFUBJ = 458
NBLKXS = 268
NCUGUC = 256
NEJNIB = "".join(
    chr(c) for c in [73, 78, 86, 65, 76, 73, 68, 95, 82, 69, 81, 85, 69, 83, 84]
)
NELWUE = "".join(chr(c) for c in [67, 70, 71, 49, 53])
NFZCZO = 478
NHTBJE = "".join(chr(c) for c in [85, 76])
NIBXTI = "".join(
    chr(c) for c in [82, 104, 70, 108, 111, 68, 101, 116, 101, 99, 116, 101, 100]
)
NIBXYB = "".join(chr(c) for c in [69, 69, 49, 95, 69, 69, 50, 95, 69, 82, 82])
NKMLOI = "".join(chr(c) for c in [75, 56])
NMHXEK = 383
NNXWEE = "".join(chr(c) for c in [67, 70, 71, 49, 57])
NPYYLI = "".join(chr(c) for c in [80, 65, 82, 84, 73, 65, 76])
NQGVUN = "".join(chr(c) for c in [70, 117, 108, 108])
NQJYMO = 264
NQLNMH = 350
NQTMFZ = 322
NRJZTA = "".join(chr(c) for c in [80, 51, 76])
NRSJMC = 306
NRXCHW = 361
NXNKML = "".join(chr(c) for c in [75, 52, 48, 48])
NXWEEZ = 467
NZMJIG = 380
OACMCV = 340
OAWBSI = 280
OCTHBS = 2
OGMDDP = 455
OIHBXI = "".join(chr(c) for c in [83, 79, 117, 116, 56])
OIJUGS = "".join(chr(c) for c in [75, 49, 48, 48])
OINELW = "".join(chr(c) for c in [67, 70, 71, 49, 52])
OJRJHI = "".join(chr(c) for c in [85, 100, 87, 97, 116, 101, 114, 102, 97, 108, 108])
OLSIPM = 371
ONFZCZ = "".join(chr(c) for c in [67, 70, 71, 51, 48])
ONPYYL = "".join(chr(c) for c in [85, 78, 76, 79, 67, 75])
OOQNRS = "".join(chr(c) for c in [85, 100, 76, 105, 103, 104, 116, 84, 105, 109, 101])
OPHUGT = 294
OQNRSJ = 305
OUNBLK = 267
OUSPBW = "".join(
    chr(c)
    for c in [
        70,
        105,
        108,
        116,
        83,
        117,
        115,
        112,
        101,
        110,
        100,
        101,
        100,
        66,
        121,
        79,
        84,
    ]
)
OUYNQJ = "".join(chr(c) for c in [65, 67, 84, 73, 86, 69])
PBWJYK = "".join(
    chr(c) for c in [83, 119, 109, 80, 117, 114, 103, 101, 83, 117, 115, 112]
)
PFTSIF = "".join(
    chr(c) for c in [83, 108, 97, 118, 101, 83, 119, 109, 65, 99, 116, 105, 118, 101]
)
PHUGTY = "".join(
    chr(c) for c in [80, 97, 99, 107, 67, 111, 110, 102, 105, 103, 76, 105, 98]
)
PHUOJR = 308
PICXQI = "".join(
    chr(c)
    for c in [
        80,
        114,
        111,
        103,
        79,
        117,
        116,
        112,
        117,
        116,
        85,
        115,
        101,
        114,
        79,
        102,
        102,
    ]
)
PIVLAS = 385
PMDMPS = 373
PMXFUB = "".join(chr(c) for c in [67, 70, 71, 49, 48])
POUYNQ = "".join(chr(c) for c in [78, 69, 87])
PQIPOU = "".join(chr(c) for c in [73, 68, 76, 69])
PSCTTG = "".join(chr(c) for c in [77, 79, 68, 69, 95, 49, 95, 70, 65, 73, 76])
PUNRJZ = "".join(chr(c) for c in [80, 50, 76])
PYYLIU = "".join(chr(c) for c in [70, 85, 76, 76])
QBMJVH = "".join(chr(c) for c in [72, 111, 117, 114, 115])
QEXLSX = "".join(chr(c) for c in [80, 52])
QFFTTI = "".join(chr(c) for c in [70, 76, 67, 69, 114, 114])
QFYLJU = "".join(
    chr(c)
    for c in [
        67,
        111,
        111,
        108,
        90,
        111,
        110,
        101,
        68,
        101,
        116,
        101,
        99,
        116,
        101,
        100,
    ]
)
QGLRAH = "".join(chr(c) for c in [85, 100, 80, 49])
QIEFXQ = "".join(chr(c) for c in [78, 79, 84, 95, 83, 69, 84])
QIPOUY = "".join(chr(c) for c in [83, 84, 79, 80])
QJYMOU = "".join(
    chr(c)
    for c in [
        82,
        101,
        109,
        111,
        116,
        101,
        70,
        105,
        108,
        116,
        68,
        117,
        114,
        80,
        101,
        114,
        68,
        97,
        121,
    ]
)
QLAIID = "".join(
    chr(c)
    for c in [83, 108, 97, 118, 101, 82, 101, 103, 79, 118, 101, 114, 72, 101, 97, 116]
)
QLNMHX = "".join(
    chr(c)
    for c in [
        83,
        108,
        97,
        118,
        101,
        72,
        116,
        114,
        50,
        83,
        117,
        115,
        112,
        101,
        110,
        100,
        66,
        121,
        80,
        119,
        114,
        77,
        110,
        103,
    ]
)
QNRSJM = "".join(chr(c) for c in [85, 100, 76, 49, 50, 48, 84, 105, 109, 101])
QNRXCH = "".join(chr(c) for c in [75, 101, 121, 112, 97, 100, 82, 101, 108])
QPLSPF = "".join(chr(c) for c in [69, 88, 84, 82, 69, 77, 69])
QRJJJV = "".join(chr(c) for c in [75, 54, 48, 48])
QSNQLN = "".join(
    chr(c)
    for c in [
        72,
        116,
        114,
        50,
        83,
        117,
        115,
        112,
        101,
        110,
        100,
        66,
        121,
        80,
        119,
        114,
        77,
        110,
        103,
    ]
)
QTDKHT = 348
QTMFZD = "".join(chr(c) for c in [83, 79, 117, 116, 52])
QVXOIH = "".join(chr(c) for c in [70, 97, 110])
QXPICX = 388
RAHEOC = "".join(chr(c) for c in [72, 73])
RAZMKQ = "".join(chr(c) for c in [83, 79, 117, 116, 49, 50, 67, 117, 114])
RHYUAX = "".join(
    chr(c) for c in [105, 110, 70, 108, 111, 74, 117, 115, 116, 82, 101, 115, 101, 116]
)
RJHIUS = "".join(chr(c) for c in [85, 100, 65, 117, 120])
RJJJVY = "".join(chr(c) for c in [105, 110, 84, 101, 114, 102, 97, 99, 101])
RJZTAT = "".join(chr(c) for c in [80, 52, 72])
RKINEJ = 379
ROGMDD = "".join(chr(c) for c in [67, 70, 71, 55])
RSJMCB = "".join(
    chr(c)
    for c in [85, 100, 87, 97, 116, 101, 114, 70, 97, 108, 108, 84, 105, 109, 101]
)
RTFMNH = "".join(chr(c) for c in [52, 56, 75])
RURAZM = "".join(chr(c) for c in [83, 79, 117, 116, 49, 49, 67, 117, 114])
RXAIVE = 472
RXCHWD = "".join(chr(c) for c in [80, 97, 99, 107, 82, 101, 115, 101, 116])
RYXBQF = "".join(
    chr(c)
    for c in [83, 105, 100, 101, 72, 101, 97, 116, 105, 110, 103, 68, 101, 103, 71]
)
SAKQXP = 386
SBDJQR = "".join(chr(c) for c in [77, 73, 65])
SCTTGC = "".join(
    chr(c) for c in [77, 79, 68, 69, 95, 49, 95, 65, 78, 68, 95, 50, 95, 70, 65, 73, 76]
)
SEMCGE = 329
SIFJBI = "".join(chr(c) for c in [79, 118, 101, 114, 84, 101, 109, 112])
SIPMDM = 372
SIRYXB = "".join(
    chr(c) for c in [83, 108, 97, 118, 101, 79, 118, 101, 114, 84, 101, 109, 112]
)
SJMCBF = 362
SJWMNZ = "".join(
    chr(c)
    for c in [
        82,
        101,
        109,
        111,
        116,
        101,
        66,
        114,
        101,
        97,
        107,
        101,
        114,
        73,
        110,
        100,
        101,
        120,
    ]
)
SKWIVD = 300
SNQLNM = "".join(
    chr(c)
    for c in [
        83,
        108,
        97,
        118,
        101,
        72,
        116,
        114,
        83,
        117,
        115,
        112,
        101,
        110,
        100,
        66,
        121,
        80,
        119,
        114,
        77,
        110,
        103,
    ]
)
SOKPHU = "".join(chr(c) for c in [79, 78])
SOOQNR = 304
SPBWJY = "".join(chr(c) for c in [67, 80, 79, 84])
SPFTSI = 353
SROGMD = 454
SRURAZ = 344
SSAKQX = "".join(
    chr(c)
    for c in [
        69,
        120,
        101,
        114,
        99,
        105,
        115,
        101,
        73,
        110,
        116,
        101,
        110,
        115,
        105,
        116,
        121,
    ]
)
SSRURA = "".join(chr(c) for c in [83, 79, 117, 116, 49, 48, 67, 117, 114])
SSUHBV = "".join(
    chr(c)
    for c in [83, 108, 97, 118, 101, 82, 101, 103, 80, 114, 111, 98, 101, 69, 114, 114]
)
STSEMC = 328
SUHBVW = "".join(
    chr(c) for c in [83, 108, 97, 118, 101, 82, 101, 103, 83, 108, 111, 112, 101]
)
SXUJUT = "".join(chr(c) for c in [66, 76])
TACCPQ = "".join(chr(c) for c in [82, 69, 77, 79, 84, 69])
TATDZX = "".join(chr(c) for c in [70, 117, 108, 108, 79, 110])
TDKHTZ = "".join(chr(c) for c in [67, 70, 71, 48])
TDRXAI = 471
TFMNHT = "".join(chr(c) for c in [54, 52, 75])
THBSKS = "".join(chr(c) for c in [85, 100, 80, 52])
THECVY = "".join(chr(c) for c in [78, 79, 82, 77, 65, 76])
TIACQF = "".join(
    chr(c) for c in [82, 104, 72, 114, 75, 105, 110, 78, 111, 70, 108, 111]
)
TIDUBS = 314
TIXQVX = 333
TMFZDG = 323
TOPHUG = "".join(chr(c) for c in [80, 97, 99, 107, 67, 111, 114, 101, 82, 101, 108])
TSEMCG = "".join(chr(c) for c in [83, 79, 117, 116, 51, 67, 117, 114])
TSIFJB = 355
TTGCRH = "".join(chr(c) for c in [72, 69, 65, 84, 73, 78, 71, 95, 70, 65, 73, 76])
TTIDUB = "".join(
    chr(c)
    for c in [83, 108, 97, 118, 101, 70, 108, 111, 68, 101, 116, 101, 99, 116, 101, 100]
)
TYEKCW = "".join(chr(c) for c in [77, 83, 84, 82, 95, 72, 69, 65, 84, 69, 82])
TYIYWS = "".join(chr(c) for c in [80, 97, 99, 107, 67, 111, 110, 102, 73, 68])
TZBBEK = "".join(chr(c) for c in [67, 70, 71, 50])
UBJLOI = "".join(chr(c) for c in [67, 70, 71, 49, 50])
UBSSUH = "".join(
    chr(c) for c in [83, 108, 97, 118, 101, 78, 111, 70, 108, 111, 69, 114, 114]
)
UBYGDS = "".join(chr(c) for c in [80, 97, 99, 107, 84, 121, 112, 101])
UEUHNN = "".join(chr(c) for c in [67, 70, 71, 49, 55])
UGSELH = "".join(chr(c) for c in [75, 51, 48, 48])
UGTYIY = "".join(
    chr(c) for c in [80, 97, 99, 107, 83, 116, 97, 116, 117, 115, 76, 105, 98]
)
UHBVWV = "".join(chr(c) for c in [80, 97, 99, 107, 66, 111, 111, 116, 73, 68])
UHNNXW = "".join(chr(c) for c in [67, 70, 71, 49, 56])
UIKFWR = "".join(chr(c) for c in [72, 80, 67, 65, 117, 116, 111, 77, 111, 100, 101])
UJUTYE = "".join(chr(c) for c in [79, 51])
UNBLKX = "".join(
    chr(c) for c in [82, 101, 109, 111, 116, 101, 69, 99, 111, 110, 68, 117, 114]
)
UNRJZT = "".join(chr(c) for c in [80, 51, 72])
UNXNKM = "".join(chr(c) for c in [75, 50, 48, 48])
UOJRJH = 307
UQEXLS = "".join(chr(c) for c in [80, 51])
URAZMK = 345
USOOQN = "".join(chr(c) for c in [85, 100, 81, 117, 105, 101, 116, 84, 105, 109, 101])
USPBWJ = "".join(
    chr(c)
    for c in [
        70,
        105,
        108,
        116,
        83,
        117,
        115,
        112,
        101,
        110,
        100,
        101,
        100,
        66,
        121,
        69,
        114,
        114,
    ]
)
UTOPHU = 293
UTYEKC = "".join(chr(c) for c in [76, 49, 50, 48])
UXFEFJ = 365
VCYWON = "".join(chr(c) for c in [67, 70, 71, 50, 56])
VDNQGV = 316
VDQLAI = "".join(
    chr(c)
    for c in [83, 108, 97, 118, 101, 75, 105, 110, 80, 117, 109, 112, 79, 102, 102]
)
VDSSRU = "".join(chr(c) for c in [83, 79, 117, 116, 57, 67, 117, 114])
VEMVCY = 474
VHFTHE = 6
VKZILX = "".join(chr(c) for c in [82, 101, 103, 79, 118, 101, 114, 72, 101, 97, 116])
VLASSA = "".join(chr(c) for c in [83, 87, 73, 77, 95, 69, 88, 69, 82, 67, 73, 83, 69])
VOACMC = "".join(chr(c) for c in [83, 79, 117, 116, 54, 67, 117, 114])
VUBYGD = 288
VUNXNK = 357
VWVUBY = 287
VYFCRT = "".join(chr(c) for c in [80, 97, 99, 107, 77, 101, 109, 82, 97, 110, 103, 101])
VYYPIP = "".join(
    chr(c) for c in [65, 99, 99, 101, 115, 115, 111, 114, 121, 79, 112, 116]
)
WAJVDQ = "".join(
    chr(c) for c in [83, 108, 97, 118, 101, 80, 50, 72, 83, 116, 117, 99, 107]
)
WAONPY = "".join(chr(c) for c in [76, 111, 99, 107, 77, 111, 100, 101])
WBSIRY = 281
WEEZFE = 468
WIVDNQ = 301
WJYKLG = "".join(chr(c) for c in [83, 119, 109, 80, 117, 114, 103, 101])
WMNZMJ = "".join(
    chr(c)
    for c in [80, 114, 111, 103, 79, 117, 116, 112, 117, 116, 65, 99, 99, 101, 115, 115]
)
WONFZC = 477
WRKINE = "".join(chr(c) for c in [72, 80, 67, 83, 116, 97, 116, 101])
WSKWIV = "".join(chr(c) for c in [80, 97, 99, 107, 67, 111, 110, 102, 82, 101, 108])
WUEUHN = 464
WVUBYG = "".join(chr(c) for c in [80, 97, 99, 107, 66, 111, 111, 116, 82, 101, 108])
XAIVEM = "".join(chr(c) for c in [67, 70, 71, 50, 53])
XBQFYL = "".join(
    chr(c) for c in [73, 110, 71, 114, 105, 100, 68, 101, 116, 101, 99, 116, 101, 100]
)
XCHWDA = 376
XEKVKZ = "".join(
    chr(c) for c in [65, 109, 98, 105, 97, 110, 116, 79, 72, 76, 101, 118, 101, 108, 50]
)
XFEFJT = "".join(
    chr(c) for c in [68, 101, 97, 108, 101, 114, 76, 111, 99, 107, 75, 101, 121]
)
XFUBJL = "".join(chr(c) for c in [67, 70, 71, 49, 49])
XIBHZV = "".join(chr(c) for c in [83, 79, 117, 116, 49, 50])
XLSXUJ = 260
XNCUGU = 64
XNKMLO = "".join(chr(c) for c in [75, 56, 53])
XNQTMF = "".join(chr(c) for c in [83, 79, 117, 116, 51])
XOIHBX = "".join(chr(c) for c in [83, 79, 117, 116, 55])
XPICXQ = 0
XQIEFX = 257
XQVXOI = 325
XSJWMN = 271
XTIACQ = "".join(chr(c) for c in [82, 104, 82, 101, 103, 83, 108, 111, 112, 101])
XUJUTY = "".join(chr(c) for c in [67, 80])
XWAJVD = "".join(
    chr(c) for c in [83, 108, 97, 118, 101, 80, 49, 72, 83, 116, 117, 99, 107]
)
XWEEZF = "".join(chr(c) for c in [67, 70, 71, 50, 48])
YBQSNQ = "".join(
    chr(c)
    for c in [
        72,
        116,
        114,
        83,
        117,
        115,
        112,
        101,
        110,
        100,
        66,
        121,
        80,
        119,
        114,
        77,
        110,
        103,
    ]
)
YEKCWA = 5
YFCRTF = 290
YGDSBD = "".join(chr(c) for c in [85, 110, 107, 110, 111, 119, 110])
YIYWSK = 297
YKLGQP = "".join(chr(c) for c in [83, 119, 109, 82, 105, 115, 107])
YLIUXF = "".join(
    chr(c)
    for c in [68, 101, 97, 108, 101, 114, 76, 111, 99, 107, 83, 116, 97, 116, 117, 115]
)
YLJUIK = "".join(
    chr(c)
    for c in [
        72,
        80,
        67,
        82,
        101,
        115,
        72,
        101,
        97,
        116,
        101,
        114,
        82,
        101,
        113,
        117,
        101,
        115,
        116,
    ]
)
YMOUNB = "".join(
    chr(c) for c in [69, 99, 111, 110, 111, 109, 121, 65, 99, 99, 101, 115, 115]
)
YNQJYM = "".join(
    chr(c) for c in [82, 101, 109, 111, 116, 101, 70, 105, 108, 116, 68, 117, 114]
)
YOUSPB = "".join(
    chr(c)
    for c in [70, 105, 108, 116, 83, 117, 115, 112, 101, 110, 100, 66, 121, 85, 68]
)
YPIPIV = "".join(chr(c) for c in [83, 116, 105, 99, 107, 66, 97, 110, 107])
YUAXNC = "".join(chr(c) for c in [76, 73])
YWONFZ = "".join(chr(c) for c in [67, 70, 71, 50, 57])
YWSKWI = 299
YXBQFY = 377
YYPIPI = "".join(
    chr(c) for c in [67, 111, 110, 102, 105, 103, 83, 101, 108, 101, 99, 116]
)
ZBBEKB = 450
ZCQBMJ = "".join(chr(c) for c in [82, 104, 87, 97, 116, 101, 114, 84, 101, 109, 112])
ZCZOLS = 479
ZDGKEA = "".join(chr(c) for c in [83, 79, 117, 116, 72, 116, 114])
ZFETDR = "".join(chr(c) for c in [67, 70, 71, 50, 50])
ZILXWA = "".join(chr(c) for c in [80, 50, 72, 83, 116, 117, 99, 107])
ZMJIGY = "".join(
    chr(c)
    for c in [
        82,
        101,
        109,
        111,
        116,
        101,
        80,
        114,
        111,
        103,
        79,
        117,
        116,
        112,
        117,
        116,
        68,
        117,
        114,
    ]
)
ZMKQTD = "".join(chr(c) for c in [83, 68, 105, 114, 101, 99, 116, 67, 117, 114])
ZOLSIP = "".join(chr(c) for c in [105, 110, 70, 108, 111, 82, 97, 116, 105, 111])
ZTATDZ = "".join(chr(c) for c in [66, 76, 79])
ZUQEXL = "".join(chr(c) for c in [80, 50])
ZVOACM = "".join(chr(c) for c in [83, 68, 105, 114, 101, 99, 116, 50])
ZXNQTM = 321
ACCPQI = [JTACCP, TACCPQ]
AHEOCT = [FXQGLR, LRAHEO, RAHEOC]
AMJMAO = [HECVYY, IAMJMA, IAMJMA, IAMJMA]
ASSAKQ = [IVLASS, VLASSA, LASSAK]
AXNCUG = [
    QGLRAH,
    EOCTHB,
    CTHBSK,
    THBSKS,
    HBSKSO,
    KSOKPH,
    KPHUOJ,
    HUOJRJ,
    OJRJHI,
    RJHIUS,
    HIUSOO,
    USOOQN,
    OOQNRS,
    QNRSJM,
    RSJMCB,
    JMCBFE,
]
CQFFTT = [HECVYY, ACQFFT, ACQFFT, ACQFFT]
FMNHTB = [FCRTFM, CRTFMN, RTFMNH, TFMNHT]
FWRKIN = [IKFWRK, KFWRKI]
GZUQEX = [FXQGLR, FEGZUQ, EGZUQE]
HYUAXN = []
HZVOAC = [
    FIKJPU,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    XUJUTY,
]
JVYFCR = [
    YGDSBD,
    GDSBDJ,
    DSBDJQ,
    SBDJQR,
    BDJQRJ,
    DJQRJJ,
    JQRJJJ,
    QRJJJV,
    RJJJVY,
    JJJVYF,
    JJVYFC,
]
KEAKST = [
    FIKJPU,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    GKEAKS,
]
LSXUJU = [FXQGLR, FEGZUQ]
OKPHUO = [FXQGLR, SOKPHU]
PIPIVL = [
    THECVY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    ECVYYP,
    CVYYPI,
    VYYPIP,
    YYPIPI,
    HECVYY,
    YPIPIV,
]
PLSPFT = [LGQPLS, LRAHEO, GQPLSP, RAHEOC, QPLSPF]
QGVUNX = [DNQGVU, NQGVUN]
SELHBQ = [
    UNXNKM,
    NXNKML,
    XNKMLO,
    NKMLOI,
    KMLOIJ,
    MLOIJU,
    LOIJUG,
    OIJUGS,
    IJUGSE,
    HECVYY,
    HECVYY,
    HECVYY,
    JUGSEL,
    UGSELH,
    GSELHB,
]
SKSOKP = [FXQGLR, RAHEOC]
TBJEUT = [NHTBJE, HTBJEU]
TDZXNQ = [
    FIKJPU,
    IKJPUN,
    KJPUNR,
    JPUNRJ,
    PUNRJZ,
    UNRJZT,
    NRJZTA,
    RJZTAT,
    JZTATD,
    EXLSXU,
    ZTATDZ,
    XUJUTY,
    UJUTYE,
    UTYEKC,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    TATDZX,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    KCWAON,
    ATDZXN,
]
TGCRHY = [MPSCTT, PSCTTG, SCTTGC, CTTGCR, TTGCRH]
UAXNCU = [
    CBFEGZ,
    ZUQEXL,
    UQEXLS,
    QEXLSX,
    EXLSXU,
    SXUJUT,
    XUJUTY,
    UJUTYE,
    UTYEKC,
    TYEKCW,
    EKCWAO,
    KCWAON,
    WAONPY,
    YLIUXF,
    IUXFEF,
    XFEFJT,
    YUAXNC,
]
UYNQJY = [PQIPOU, QIPOUY, IPOUYN, POUYNQ, OUYNQJ]
VXOIHB = [
    FIKJPU,
    IKJPUN,
    KJPUNR,
    JPUNRJ,
    PUNRJZ,
    UNRJZT,
    NRJZTA,
    RJZTAT,
    JZTATD,
    EXLSXU,
    ZTATDZ,
    XUJUTY,
    UJUTYE,
    UTYEKC,
    HECVYY,
    HECVYY,
    QVXOIH,
    HECVYY,
    HECVYY,
    TATDZX,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    KCWAON,
    ATDZXN,
]
WDAFIK = [CHWDAF, HWDAFI]
XQGLRA = [QIEFXQ, IEFXQG, EFXQGL, FXQGLR]
XYBQSN = [
    PQIPOU,
    KINEJN,
    INEJNI,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    HECVYY,
    NEJNIB,
    EJNIBX,
    JNIBXY,
    NIBXYB,
    IBXYBQ,
    BXYBQS,
]
YYLIUX = [ONPYYL, NPYYLI, PYYLIU]


class GeckoLogStruct:
    def __init__(self, struct_):
        self.struct = struct_

    @property
    def version(self):
        return XNCUGU

    @property
    def begin(self):
        return NCUGUC

    @property
    def end(self):
        return CUGUCY

    @property
    def all_device_keys(self):
        return UAXNCU

    @property
    def user_demand_keys(self):
        return AXNCUG

    @property
    def accessors(self):
        return {
            ZCQBMJ: GeckoTempStructAccessor(self.struct, ZCQBMJ, CQBMJV, None),
            QBMJVH: GeckoByteStructAccessor(self.struct, QBMJVH, BMJVHF, None),
            MJVHFT: GeckoBoolStructAccessor(self.struct, MJVHFT, JVHFTH, VHFTHE, None),
            HFTHEC: GeckoEnumStructAccessor(
                self.struct, HFTHEC, FTHECV, None, PIPIVL, None, None, None
            ),
            IPIVLA: GeckoEnumStructAccessor(
                self.struct, IPIVLA, PIVLAS, None, ASSAKQ, None, None, None
            ),
            SSAKQX: GeckoByteStructAccessor(self.struct, SSAKQX, SAKQXP, AKQXPI),
            KQXPIC: GeckoBoolStructAccessor(self.struct, KQXPIC, QXPICX, XPICXQ, None),
            PICXQI: GeckoBoolStructAccessor(self.struct, PICXQI, QXPICX, ICXQIE, None),
            CXQIEF: GeckoEnumStructAccessor(
                self.struct, CXQIEF, XQIEFX, None, XQGLRA, None, None, AKQXPI
            ),
            QGLRAH: GeckoEnumStructAccessor(
                self.struct, QGLRAH, GLRAHE, XPICXQ, AHEOCT, None, HEOCTH, AKQXPI
            ),
            EOCTHB: GeckoEnumStructAccessor(
                self.struct, EOCTHB, GLRAHE, OCTHBS, AHEOCT, None, HEOCTH, AKQXPI
            ),
            CTHBSK: GeckoEnumStructAccessor(
                self.struct, CTHBSK, GLRAHE, HEOCTH, AHEOCT, None, HEOCTH, AKQXPI
            ),
            THBSKS: GeckoEnumStructAccessor(
                self.struct, THBSKS, GLRAHE, VHFTHE, AHEOCT, None, HEOCTH, AKQXPI
            ),
            HBSKSO: GeckoEnumStructAccessor(
                self.struct, HBSKSO, BSKSOK, XPICXQ, SKSOKP, None, OCTHBS, AKQXPI
            ),
            KSOKPH: GeckoEnumStructAccessor(
                self.struct, KSOKPH, BSKSOK, ICXQIE, OKPHUO, None, OCTHBS, AKQXPI
            ),
            KPHUOJ: GeckoEnumStructAccessor(
                self.struct, KPHUOJ, PHUOJR, None, OKPHUO, None, None, AKQXPI
            ),
            HUOJRJ: GeckoEnumStructAccessor(
                self.struct, HUOJRJ, UOJRJH, None, SKSOKP, None, None, AKQXPI
            ),
            OJRJHI: GeckoEnumStructAccessor(
                self.struct, OJRJHI, JRJHIU, None, OKPHUO, None, None, AKQXPI
            ),
            RJHIUS: GeckoEnumStructAccessor(
                self.struct, RJHIUS, JHIUSO, None, OKPHUO, None, None, AKQXPI
            ),
            HIUSOO: GeckoByteStructAccessor(self.struct, HIUSOO, IUSOOQ, AKQXPI),
            USOOQN: GeckoByteStructAccessor(self.struct, USOOQN, SOOQNR, AKQXPI),
            OOQNRS: GeckoByteStructAccessor(self.struct, OOQNRS, OQNRSJ, AKQXPI),
            QNRSJM: GeckoByteStructAccessor(self.struct, QNRSJM, NRSJMC, AKQXPI),
            RSJMCB: GeckoByteStructAccessor(self.struct, RSJMCB, SJMCBF, AKQXPI),
            JMCBFE: GeckoByteStructAccessor(self.struct, JMCBFE, MCBFEG, AKQXPI),
            CBFEGZ: GeckoEnumStructAccessor(
                self.struct, CBFEGZ, BFEGZU, XPICXQ, GZUQEX, None, HEOCTH, None
            ),
            ZUQEXL: GeckoEnumStructAccessor(
                self.struct, ZUQEXL, BFEGZU, OCTHBS, GZUQEX, None, HEOCTH, None
            ),
            UQEXLS: GeckoEnumStructAccessor(
                self.struct, UQEXLS, BFEGZU, HEOCTH, GZUQEX, None, HEOCTH, None
            ),
            QEXLSX: GeckoEnumStructAccessor(
                self.struct, QEXLSX, BFEGZU, VHFTHE, GZUQEX, None, HEOCTH, None
            ),
            EXLSXU: GeckoEnumStructAccessor(
                self.struct, EXLSXU, XLSXUJ, XPICXQ, LSXUJU, None, OCTHBS, None
            ),
            SXUJUT: GeckoEnumStructAccessor(
                self.struct, SXUJUT, XLSXUJ, ICXQIE, OKPHUO, None, OCTHBS, None
            ),
            XUJUTY: GeckoEnumStructAccessor(
                self.struct, XUJUTY, XLSXUJ, OCTHBS, OKPHUO, None, OCTHBS, None
            ),
            UJUTYE: GeckoEnumStructAccessor(
                self.struct, UJUTYE, XLSXUJ, JUTYEK, OKPHUO, None, OCTHBS, None
            ),
            UTYEKC: GeckoEnumStructAccessor(
                self.struct, UTYEKC, XLSXUJ, HEOCTH, OKPHUO, None, OCTHBS, None
            ),
            TYEKCW: GeckoEnumStructAccessor(
                self.struct, TYEKCW, XLSXUJ, YEKCWA, OKPHUO, None, OCTHBS, None
            ),
            EKCWAO: GeckoEnumStructAccessor(
                self.struct, EKCWAO, XLSXUJ, VHFTHE, OKPHUO, None, OCTHBS, None
            ),
            KCWAON: GeckoEnumStructAccessor(
                self.struct, KCWAON, XLSXUJ, CWAONP, OKPHUO, None, OCTHBS, None
            ),
            WAONPY: GeckoEnumStructAccessor(
                self.struct, WAONPY, AONPYY, None, YYLIUX, None, None, AKQXPI
            ),
            YLIUXF: GeckoEnumStructAccessor(
                self.struct, YLIUXF, LIUXFE, None, YYLIUX, None, None, None
            ),
            IUXFEF: GeckoWordStructAccessor(self.struct, IUXFEF, UXFEFJ, None),
            XFEFJT: GeckoWordStructAccessor(self.struct, XFEFJT, FEFJTA, AKQXPI),
            EFJTAC: GeckoEnumStructAccessor(
                self.struct, EFJTAC, FJTACC, XPICXQ, ACCPQI, None, OCTHBS, AKQXPI
            ),
            CCPQIP: GeckoEnumStructAccessor(
                self.struct, CCPQIP, CPQIPO, None, UYNQJY, None, None, AKQXPI
            ),
            YNQJYM: GeckoTimeStructAccessor(self.struct, YNQJYM, NQJYMO, AKQXPI),
            QJYMOU: GeckoByteStructAccessor(self.struct, QJYMOU, JYMOUN, AKQXPI),
            YMOUNB: GeckoEnumStructAccessor(
                self.struct, YMOUNB, FJTACC, OCTHBS, ACCPQI, None, OCTHBS, AKQXPI
            ),
            MOUNBL: GeckoEnumStructAccessor(
                self.struct, MOUNBL, OUNBLK, None, UYNQJY, None, None, AKQXPI
            ),
            UNBLKX: GeckoTimeStructAccessor(self.struct, UNBLKX, NBLKXS, AKQXPI),
            BLKXSJ: GeckoByteStructAccessor(self.struct, BLKXSJ, LKXSJW, AKQXPI),
            KXSJWM: GeckoByteStructAccessor(self.struct, KXSJWM, XSJWMN, AKQXPI),
            SJWMNZ: GeckoByteStructAccessor(self.struct, SJWMNZ, JWMNZM, AKQXPI),
            WMNZMJ: GeckoEnumStructAccessor(
                self.struct, WMNZMJ, FJTACC, ICXQIE, ACCPQI, None, OCTHBS, AKQXPI
            ),
            MNZMJI: GeckoEnumStructAccessor(
                self.struct, MNZMJI, NZMJIG, None, UYNQJY, None, None, AKQXPI
            ),
            ZMJIGY: GeckoTimeStructAccessor(self.struct, ZMJIGY, MJIGYO, AKQXPI),
            JIGYOU: GeckoBoolStructAccessor(self.struct, JIGYOU, IGYOUS, XPICXQ, None),
            GYOUSP: GeckoBoolStructAccessor(self.struct, GYOUSP, IGYOUS, OCTHBS, None),
            YOUSPB: GeckoBoolStructAccessor(self.struct, YOUSPB, IGYOUS, JUTYEK, None),
            OUSPBW: GeckoBoolStructAccessor(self.struct, OUSPBW, IGYOUS, HEOCTH, None),
            USPBWJ: GeckoBoolStructAccessor(self.struct, USPBWJ, IGYOUS, YEKCWA, None),
            SPBWJY: GeckoBoolStructAccessor(self.struct, SPBWJY, JVHFTH, OCTHBS, None),
            PBWJYK: GeckoBoolStructAccessor(self.struct, PBWJYK, BWJYKL, JUTYEK, None),
            WJYKLG: GeckoBoolStructAccessor(self.struct, WJYKLG, BWJYKL, YEKCWA, None),
            JYKLGQ: GeckoBoolStructAccessor(self.struct, JYKLGQ, BWJYKL, VHFTHE, None),
            YKLGQP: GeckoEnumStructAccessor(
                self.struct, YKLGQP, KLGQPL, None, PLSPFT, None, None, None
            ),
            LSPFTS: GeckoBoolStructAccessor(self.struct, LSPFTS, SPFTSI, YEKCWA, None),
            PFTSIF: GeckoBoolStructAccessor(self.struct, PFTSIF, SPFTSI, VHFTHE, None),
            FTSIFJ: GeckoWordStructAccessor(self.struct, FTSIFJ, TSIFJB, None),
            SIFJBI: GeckoBoolStructAccessor(self.struct, SIFJBI, JVHFTH, ICXQIE, None),
            IFJBIA: GeckoTempStructAccessor(self.struct, IFJBIA, FJBIAM, None),
            JBIAMJ: GeckoTempStructAccessor(self.struct, JBIAMJ, BIAMJM, None),
            IAMJMA: GeckoEnumStructAccessor(
                self.struct, IAMJMA, XLSXUJ, YEKCWA, AMJMAO, None, HEOCTH, None
            ),
            MJMAOA: GeckoBoolStructAccessor(self.struct, MJMAOA, JMAOAW, OCTHBS, None),
            MAOAWB: GeckoBoolStructAccessor(self.struct, MAOAWB, JMAOAW, VHFTHE, None),
            AOAWBS: GeckoBoolStructAccessor(self.struct, AOAWBS, OAWBSI, OCTHBS, None),
            AWBSIR: GeckoBoolStructAccessor(self.struct, AWBSIR, WBSIRY, ICXQIE, None),
            BSIRYX: GeckoBoolStructAccessor(
                self.struct, BSIRYX, WBSIRY, OCTHBS, AKQXPI
            ),
            SIRYXB: GeckoBoolStructAccessor(self.struct, SIRYXB, IRYXBQ, ICXQIE, None),
            RYXBQF: GeckoByteStructAccessor(self.struct, RYXBQF, YXBQFY, None),
            XBQFYL: GeckoBoolStructAccessor(self.struct, XBQFYL, BQFYLJ, XPICXQ, None),
            QFYLJU: GeckoBoolStructAccessor(self.struct, QFYLJU, FYLJUI, XPICXQ, None),
            YLJUIK: GeckoBoolStructAccessor(self.struct, YLJUIK, FYLJUI, HEOCTH, None),
            LJUIKF: GeckoBoolStructAccessor(self.struct, LJUIKF, FYLJUI, YEKCWA, None),
            JUIKFW: GeckoBoolStructAccessor(self.struct, JUIKFW, FYLJUI, VHFTHE, None),
            UIKFWR: GeckoEnumStructAccessor(
                self.struct, UIKFWR, FYLJUI, CWAONP, FWRKIN, None, OCTHBS, AKQXPI
            ),
            WRKINE: GeckoEnumStructAccessor(
                self.struct, WRKINE, RKINEJ, None, XYBQSN, None, None, None
            ),
            YBQSNQ: GeckoBoolStructAccessor(self.struct, YBQSNQ, BQSNQL, XPICXQ, None),
            QSNQLN: GeckoBoolStructAccessor(self.struct, QSNQLN, BQSNQL, ICXQIE, None),
            SNQLNM: GeckoBoolStructAccessor(self.struct, SNQLNM, NQLNMH, XPICXQ, None),
            QLNMHX: GeckoBoolStructAccessor(self.struct, QLNMHX, NQLNMH, ICXQIE, None),
            LNMHXE: GeckoBoolStructAccessor(self.struct, LNMHXE, NMHXEK, XPICXQ, None),
            MHXEKV: GeckoBoolStructAccessor(self.struct, MHXEKV, JVHFTH, JUTYEK, None),
            HXEKVK: GeckoBoolStructAccessor(self.struct, HXEKVK, BWJYKL, XPICXQ, None),
            XEKVKZ: GeckoBoolStructAccessor(self.struct, XEKVKZ, BWJYKL, ICXQIE, None),
            EKVKZI: GeckoBoolStructAccessor(self.struct, EKVKZI, KVKZIL, OCTHBS, None),
            VKZILX: GeckoBoolStructAccessor(self.struct, VKZILX, KVKZIL, JUTYEK, None),
            KZILXW: GeckoBoolStructAccessor(self.struct, KZILXW, BQSNQL, JUTYEK, None),
            ZILXWA: GeckoBoolStructAccessor(self.struct, ZILXWA, BQSNQL, HEOCTH, None),
            ILXWAJ: GeckoBoolStructAccessor(self.struct, ILXWAJ, BQSNQL, YEKCWA, None),
            LXWAJV: GeckoBoolStructAccessor(self.struct, LXWAJV, BQSNQL, VHFTHE, None),
            XWAJVD: GeckoBoolStructAccessor(self.struct, XWAJVD, NQLNMH, JUTYEK, None),
            WAJVDQ: GeckoBoolStructAccessor(self.struct, WAJVDQ, NQLNMH, HEOCTH, None),
            AJVDQL: GeckoBoolStructAccessor(self.struct, AJVDQL, NQLNMH, YEKCWA, None),
            JVDQLA: GeckoBoolStructAccessor(self.struct, JVDQLA, NQLNMH, VHFTHE, None),
            VDQLAI: GeckoBoolStructAccessor(self.struct, VDQLAI, DQLAII, OCTHBS, None),
            QLAIID: GeckoBoolStructAccessor(self.struct, QLAIID, DQLAII, JUTYEK, None),
            LAIIDN: GeckoBoolStructAccessor(self.struct, LAIIDN, IRYXBQ, JUTYEK, None),
            AIIDNI: GeckoBoolStructAccessor(self.struct, AIIDNI, SPFTSI, XPICXQ, None),
            IIDNIB: GeckoBoolStructAccessor(self.struct, IIDNIB, SPFTSI, ICXQIE, None),
            IDNIBX: GeckoBoolStructAccessor(self.struct, IDNIBX, DNIBXT, XPICXQ, None),
            NIBXTI: GeckoBoolStructAccessor(self.struct, NIBXTI, OAWBSI, XPICXQ, None),
            IBXTIA: GeckoBoolStructAccessor(self.struct, IBXTIA, KVKZIL, XPICXQ, None),
            BXTIAC: GeckoBoolStructAccessor(self.struct, BXTIAC, KVKZIL, ICXQIE, None),
            XTIACQ: GeckoBoolStructAccessor(self.struct, XTIACQ, KVKZIL, HEOCTH, None),
            TIACQF: GeckoBoolStructAccessor(self.struct, TIACQF, IACQFF, XPICXQ, None),
            ACQFFT: GeckoEnumStructAccessor(
                self.struct, ACQFFT, IACQFF, ICXQIE, CQFFTT, None, HEOCTH, None
            ),
            QFFTTI: GeckoBoolStructAccessor(self.struct, QFFTTI, IACQFF, JUTYEK, None),
            FFTTID: GeckoWordStructAccessor(self.struct, FFTTID, FTTIDU, None),
            TTIDUB: GeckoBoolStructAccessor(self.struct, TTIDUB, TIDUBS, XPICXQ, None),
            IDUBSS: GeckoBoolStructAccessor(self.struct, IDUBSS, DUBSSU, XPICXQ, None),
            UBSSUH: GeckoBoolStructAccessor(self.struct, UBSSUH, DUBSSU, ICXQIE, None),
            BSSUHB: GeckoBoolStructAccessor(self.struct, BSSUHB, DQLAII, XPICXQ, None),
            SSUHBV: GeckoBoolStructAccessor(self.struct, SSUHBV, DQLAII, ICXQIE, None),
            SUHBVW: GeckoBoolStructAccessor(self.struct, SUHBVW, DQLAII, HEOCTH, None),
            UHBVWV: GeckoWordStructAccessor(self.struct, UHBVWV, HBVWVU, None),
            BVWVUB: GeckoByteStructAccessor(self.struct, BVWVUB, VWVUBY, None),
            WVUBYG: GeckoByteStructAccessor(self.struct, WVUBYG, VUBYGD, None),
            UBYGDS: GeckoEnumStructAccessor(
                self.struct, UBYGDS, BYGDSB, None, JVYFCR, None, None, None
            ),
            VYFCRT: GeckoEnumStructAccessor(
                self.struct, VYFCRT, YFCRTF, XPICXQ, FMNHTB, None, HEOCTH, None
            ),
            MNHTBJ: GeckoEnumStructAccessor(
                self.struct, MNHTBJ, YFCRTF, OCTHBS, TBJEUT, None, OCTHBS, None
            ),
            BJEUTO: GeckoWordStructAccessor(self.struct, BJEUTO, JEUTOP, None),
            EUTOPH: GeckoByteStructAccessor(self.struct, EUTOPH, UTOPHU, None),
            TOPHUG: GeckoByteStructAccessor(self.struct, TOPHUG, OPHUGT, None),
            PHUGTY: GeckoByteStructAccessor(self.struct, PHUGTY, HUGTYI, None),
            UGTYIY: GeckoByteStructAccessor(self.struct, UGTYIY, GTYIYW, None),
            TYIYWS: GeckoWordStructAccessor(self.struct, TYIYWS, YIYWSK, None),
            IYWSKW: GeckoByteStructAccessor(self.struct, IYWSKW, YWSKWI, None),
            WSKWIV: GeckoByteStructAccessor(self.struct, WSKWIV, SKWIVD, None),
            KWIVDN: GeckoWordStructAccessor(self.struct, KWIVDN, WIVDNQ, None),
            IVDNQG: GeckoEnumStructAccessor(
                self.struct, IVDNQG, VDNQGV, None, QGVUNX, None, OCTHBS, AKQXPI
            ),
            GVUNXN: GeckoEnumStructAccessor(
                self.struct, GVUNXN, VUNXNK, None, SELHBQ, None, None, None
            ),
            ELHBQN: GeckoWordStructAccessor(self.struct, ELHBQN, LHBQNR, None),
            HBQNRX: GeckoByteStructAccessor(self.struct, HBQNRX, BQNRXC, None),
            QNRXCH: GeckoByteStructAccessor(self.struct, QNRXCH, NRXCHW, None),
            RXCHWD: GeckoEnumStructAccessor(
                self.struct, RXCHWD, XCHWDA, None, WDAFIK, None, None, AKQXPI
            ),
            DAFIKJ: GeckoEnumStructAccessor(
                self.struct, DAFIKJ, AFIKJP, None, TDZXNQ, None, None, AKQXPI
            ),
            DZXNQT: GeckoEnumStructAccessor(
                self.struct, DZXNQT, ZXNQTM, None, TDZXNQ, None, None, AKQXPI
            ),
            XNQTMF: GeckoEnumStructAccessor(
                self.struct, XNQTMF, NQTMFZ, None, TDZXNQ, None, None, AKQXPI
            ),
            QTMFZD: GeckoEnumStructAccessor(
                self.struct, QTMFZD, TMFZDG, None, TDZXNQ, None, None, AKQXPI
            ),
            MFZDGK: GeckoEnumStructAccessor(
                self.struct, MFZDGK, FZDGKE, None, TDZXNQ, None, None, AKQXPI
            ),
            ZDGKEA: GeckoEnumStructAccessor(
                self.struct, ZDGKEA, DGKEAK, None, KEAKST, None, None, AKQXPI
            ),
            EAKSTS: GeckoByteStructAccessor(self.struct, EAKSTS, AKSTSE, AKQXPI),
            KSTSEM: GeckoByteStructAccessor(self.struct, KSTSEM, STSEMC, AKQXPI),
            TSEMCG: GeckoByteStructAccessor(self.struct, TSEMCG, SEMCGE, AKQXPI),
            EMCGET: GeckoByteStructAccessor(self.struct, EMCGET, MCGETI, AKQXPI),
            CGETIX: GeckoByteStructAccessor(self.struct, CGETIX, GETIXQ, AKQXPI),
            ETIXQV: GeckoByteStructAccessor(self.struct, ETIXQV, TIXQVX, AKQXPI),
            IXQVXO: GeckoEnumStructAccessor(
                self.struct, IXQVXO, XQVXOI, None, VXOIHB, None, None, AKQXPI
            ),
            XOIHBX: GeckoEnumStructAccessor(
                self.struct, XOIHBX, DGKEAK, None, VXOIHB, None, None, AKQXPI
            ),
            OIHBXI: GeckoEnumStructAccessor(
                self.struct, OIHBXI, AKSTSE, None, VXOIHB, None, None, AKQXPI
            ),
            IHBXIB: GeckoEnumStructAccessor(
                self.struct, IHBXIB, STSEMC, None, VXOIHB, None, None, AKQXPI
            ),
            HBXIBH: GeckoEnumStructAccessor(
                self.struct, HBXIBH, SEMCGE, None, VXOIHB, None, None, AKQXPI
            ),
            BXIBHZ: GeckoEnumStructAccessor(
                self.struct, BXIBHZ, MCGETI, None, VXOIHB, None, None, AKQXPI
            ),
            XIBHZV: GeckoEnumStructAccessor(
                self.struct, XIBHZV, GETIXQ, None, VXOIHB, None, None, AKQXPI
            ),
            IBHZVO: GeckoEnumStructAccessor(
                self.struct, IBHZVO, BHZVOA, None, HZVOAC, None, None, AKQXPI
            ),
            ZVOACM: GeckoEnumStructAccessor(
                self.struct, ZVOACM, TIXQVX, None, HZVOAC, None, None, AKQXPI
            ),
            VOACMC: GeckoByteStructAccessor(self.struct, VOACMC, OACMCV, AKQXPI),
            ACMCVD: GeckoByteStructAccessor(self.struct, ACMCVD, CMCVDS, AKQXPI),
            MCVDSS: GeckoByteStructAccessor(self.struct, MCVDSS, CVDSSR, AKQXPI),
            VDSSRU: GeckoByteStructAccessor(self.struct, VDSSRU, DSSRUR, AKQXPI),
            SSRURA: GeckoByteStructAccessor(self.struct, SSRURA, SRURAZ, AKQXPI),
            RURAZM: GeckoByteStructAccessor(self.struct, RURAZM, URAZMK, AKQXPI),
            RAZMKQ: GeckoByteStructAccessor(self.struct, RAZMKQ, AZMKQT, AKQXPI),
            ZMKQTD: GeckoByteStructAccessor(self.struct, ZMKQTD, MKQTDK, AKQXPI),
            KQTDKH: GeckoByteStructAccessor(self.struct, KQTDKH, QTDKHT, AKQXPI),
            CZOLSI: GeckoBoolStructAccessor(self.struct, CZOLSI, JVHFTH, YEKCWA, None),
            ZOLSIP: GeckoByteStructAccessor(self.struct, ZOLSIP, OLSIPM, AKQXPI),
            LSIPMD: GeckoByteStructAccessor(self.struct, LSIPMD, SIPMDM, AKQXPI),
            IPMDMP: GeckoByteStructAccessor(self.struct, IPMDMP, PMDMPS, AKQXPI),
            MDMPSC: GeckoEnumStructAccessor(
                self.struct, MDMPSC, DMPSCT, None, TGCRHY, None, None, AKQXPI
            ),
            GCRHYU: GeckoBoolStructAccessor(
                self.struct, GCRHYU, CRHYUA, XPICXQ, AKQXPI
            ),
            RHYUAX: GeckoBoolStructAccessor(self.struct, RHYUAX, XCHWDA, XPICXQ, None),
        }



#!/usr/bin/python3
"""
    GeckoLogStruct - A class to manage the LogStruct for 'InXM v4'
"""

from . import (
    GeckoByteStructAccessor,
    GeckoWordStructAccessor,
    GeckoTimeStructAccessor,
    GeckoBoolStructAccessor,
    GeckoEnumStructAccessor,
    GeckoTempStructAccessor,
)

# Constants for this class
ACQFFT = "".join(
    chr(c)
    for c in [82, 104, 70, 108, 111, 67, 104, 101, 99, 107, 82, 101, 97, 100, 121]
)
AFIKJP = "".join(chr(c) for c in [67, 70, 71, 49, 49])
AHEOCT = 294
AIIDNI = "".join(chr(c) for c in [82, 104, 72, 119, 84, 114, 105, 97, 99, 79, 72])
AJVDQL = "".join(
    chr(c) for c in [82, 104, 82, 101, 103, 80, 114, 111, 98, 101, 69, 114, 114]
)
AKQXPI = "".join(
    chr(c)
    for c in [72, 101, 97, 116, 101, 114, 80, 104, 97, 115, 101, 83, 105, 103, 110]
)
AKSTSE = 472
AMJMAO = "".join(chr(c) for c in [67, 80, 79, 84])
AOAWBS = 268
AONPYY = "".join(chr(c) for c in [80, 51])
ASSAKQ = "".join(chr(c) for c in [75, 54, 48, 48, 85, 112, 108, 111, 97, 100])
ATDZXN = "".join(chr(c) for c in [67, 70, 71, 49, 55])
AWBSIR = "".join(chr(c) for c in [69, 88, 84, 82, 69, 77, 69])
BDJQRJ = "".join(chr(c) for c in [54, 52, 75])
BFEGZU = "".join(chr(c) for c in [78, 65])
BIAMJM = 279
BJEUTO = 331
BLKXSJ = 348
BMJVHF = 263
BQFYLJ = "".join(
    chr(c) for c in [84, 101, 109, 112, 78, 111, 116, 86, 97, 108, 105, 100]
)
BQNRXC = 454
BQSNQL = "".join(chr(c) for c in [83, 99, 97, 110, 69, 114, 114])
BSIRYX = "".join(chr(c) for c in [83, 119, 109, 80, 117, 114, 103, 101])
BSKSOK = "".join(chr(c) for c in [79, 70, 70])
BSSUHB = "".join(chr(c) for c in [105, 110, 88, 69])
BVWVUB = "".join(chr(c) for c in [105, 110, 88, 77])
BWJYKL = "".join(
    chr(c) for c in [82, 101, 109, 111, 116, 101, 79, 110, 122, 101, 110, 68, 117, 114]
)
BXIBHZ = 256
BXTIAC = 260
BXYBQS = "".join(chr(c) for c in [70, 117, 115, 101, 49, 69, 114, 114])
BYGDSB = "".join(chr(c) for c in [80, 97, 99, 107, 77, 101, 109, 82, 97, 110, 103, 101])
CBFEGZ = "".join(chr(c) for c in [70, 73, 88])
CCPQIP = "".join(chr(c) for c in [65, 108, 119, 97, 121, 79, 110])
CGETIX = "".join(chr(c) for c in [67, 70, 71, 50, 56])
CHWDAF = "".join(chr(c) for c in [67, 70, 71, 57])
CPQIPO = "".join(chr(c) for c in [84, 118, 76, 105, 102, 116])
CQBMJV = 261
CQFFTT = "".join(chr(c) for c in [80, 97, 99, 107, 66, 111, 111, 116, 73, 68])
CRTFMN = 325
CTHBSK = 298
CVYYPI = "".join(chr(c) for c in [72, 50])
CXQIEF = "".join(chr(c) for c in [79, 85, 84, 50, 65, 82, 101, 97, 100])
DAFIKJ = 458
DGKEAK = 470
DNIBXT = "".join(chr(c) for c in [82, 104, 83, 119, 75, 105, 110, 84, 101, 109, 112])
DNQGVU = "".join(chr(c) for c in [75, 54, 48, 48, 73, 68])
DQLAII = 259
DSBDJQ = "".join(chr(c) for c in [51, 50, 75])
DUBSSU = 321
DZXNQT = "".join(chr(c) for c in [67, 70, 71, 49, 56])
EAKSTS = "".join(chr(c) for c in [67, 70, 71, 50, 52])
ECVYYP = "".join(chr(c) for c in [72, 49])
EFJTAC = "".join(chr(c) for c in [70, 65, 78])
EFXQGL = "".join(chr(c) for c in [79, 85, 84, 51, 65, 82, 101, 97, 100])
EJNIBX = "".join(
    chr(c)
    for c in [
        78,
        111,
        72,
        101,
        97,
        116,
        101,
        114,
        67,
        117,
        114,
        114,
        101,
        110,
        116,
        69,
        114,
        114,
    ]
)
EKCWAO = "".join(chr(c) for c in [72, 73, 71, 72])
EKVKZI = "".join(chr(c) for c in [82, 104, 82, 101, 103, 83, 108, 111, 112, 101])
ELHBQN = "".join(chr(c) for c in [67, 70, 71, 53])
EMCGET = "".join(chr(c) for c in [67, 70, 71, 50, 55])
EOCTHB = 296
ETIXQV = "".join(chr(c) for c in [67, 70, 71, 50, 57])
EUTOPH = 332
EXLSXU = "".join(chr(c) for c in [85, 100, 76, 105])
FCRTFM = "".join(chr(c) for c in [80, 97, 99, 107, 67, 111, 114, 101, 73, 68])
FEFJTA = "".join(chr(c) for c in [76, 49, 50, 48])
FEGZUQ = "".join(chr(c) for c in [83, 67, 65, 78])
FFTTID = "".join(chr(c) for c in [80, 97, 99, 107, 66, 111, 111, 116, 82, 101, 118])
FIKJPU = 459
FJBIAM = "".join(
    chr(c) for c in [67, 108, 101, 97, 110, 83, 117, 115, 112, 101, 110, 100, 101, 100]
)
FJTACC = 7
FMNHTB = "".join(chr(c) for c in [80, 97, 99, 107, 67, 111, 114, 101, 82, 101, 108])
FTHECV = "".join(chr(c) for c in [78, 79, 82, 77, 65, 76])
FTSIFJ = 352
FTTIDU = 319
FWRKIN = 271
FXQGLR = 288
FYLJUI = "".join(chr(c) for c in [80, 117, 109, 112, 82, 117, 110])
FZDGKE = 469
GDSBDJ = "".join(chr(c) for c in [49, 54, 75])
GETIXQ = 476
GKEAKS = "".join(chr(c) for c in [67, 70, 71, 50, 51])
GLRAHE = "".join(chr(c) for c in [79, 85, 84, 53, 65, 82, 101, 97, 100])
GQPLSP = 314
GSELHB = "".join(chr(c) for c in [67, 70, 71, 52])
GVUNXN = 345
GYOUSP = 308
GZUQEX = "".join(chr(c) for c in [85, 100, 76, 49, 50, 48])
HBQNRX = "".join(chr(c) for c in [67, 70, 71, 54])
HBSKSO = 275
HBVWVU = "".join(chr(c) for c in [105, 110, 67, 108, 101, 97, 114])
HECVYY = "".join(chr(c) for c in [83, 50])
HEOCTH = "".join(chr(c) for c in [79, 85, 84, 55, 65, 82, 101, 97, 100])
HFTHEC = 353
HIUSOO = "".join(chr(c) for c in [85, 100, 80, 52])
HTBJEU = 329
HUGTYI = "".join(chr(c) for c in [82, 101, 115, 116, 114, 105, 99, 116, 101, 100])
HUOJRJ = "".join(chr(c) for c in [65, 76, 76])
HWDAFI = 457
HXEKVK = 257
IACQFF = "".join(
    chr(c)
    for c in [
        82,
        104,
        72,
        101,
        97,
        116,
        101,
        114,
        83,
        117,
        115,
        112,
        101,
        110,
        100,
        101,
        100,
    ]
)
IAMJMA = "".join(chr(c) for c in [70, 105, 108, 116, 79, 84])
IBXTIA = "".join(
    chr(c)
    for c in [82, 104, 72, 101, 97, 116, 101, 114, 68, 105, 115, 97, 98, 108, 101, 100]
)
IBXYBQ = "".join(chr(c) for c in [70, 117, 115, 101, 50, 69, 114, 114])
ICXQIE = 282
IDNIBX = "".join(
    chr(c) for c in [82, 104, 72, 114, 75, 105, 110, 78, 111, 70, 108, 111]
)
IDUBSS = "".join(chr(c) for c in [80, 97, 99, 107, 84, 121, 112, 101])
IEFXQG = 286
IFJBIA = "".join(chr(c) for c in [67, 108, 101, 97, 110])
IGYOUS = "".join(
    chr(c) for c in [82, 101, 109, 111, 116, 101, 70, 105, 108, 116, 68, 117, 114]
)
IIDNIB = "".join(chr(c) for c in [82, 104, 72, 114, 75, 105, 110])
IJUGSE = 450
IKFWRK = "".join(
    chr(c) for c in [75, 105, 110, 80, 117, 114, 103, 101, 65, 99, 116, 105, 118, 101]
)
IKJPUN = "".join(chr(c) for c in [67, 70, 71, 49, 50])
ILXWAJ = "".join(chr(c) for c in [82, 104, 78, 111, 70, 108, 111, 84, 101, 109, 112])
INEJNI = "".join(
    chr(c)
    for c in [84, 104, 101, 114, 109, 105, 115, 116, 97, 110, 99, 101, 69, 114, 114]
)
IPIVLA = "".join(chr(c) for c in [76, 101, 97, 114, 110, 105, 110, 103])
IRYXBQ = "".join(
    chr(c) for c in [82, 101, 97, 108, 83, 101, 116, 80, 111, 105, 110, 116, 71]
)
IUSOOQ = 10
IUXFEF = "".join(chr(c) for c in [67, 80])
IVDNQG = "".join(
    chr(c) for c in [105, 110, 84, 104, 101, 114, 109, 67, 117, 114, 70, 117, 108, 108]
)
IVLASS = "".join(chr(c) for c in [80, 104, 97, 115, 101, 83, 101, 108, 101, 99, 116])
IXQVXO = "".join(chr(c) for c in [67, 70, 71, 51, 48])
IYWSKW = "".join(chr(c) for c in [105, 110, 84, 104, 101, 114, 109, 82, 101, 118])
JBIAMJ = "".join(
    chr(c) for c in [67, 108, 101, 97, 110, 83, 117, 115, 112, 101, 110, 100, 85, 68]
)
JEUTOP = "".join(chr(c) for c in [80, 97, 99, 107, 67, 111, 110, 102, 82, 101, 108])
JHIUSO = 11
JJVYFC = "".join(
    chr(c) for c in [80, 97, 99, 107, 83, 116, 97, 116, 117, 115, 76, 105, 98]
)
JMAOAW = 267
JMCBFE = "".join(chr(c) for c in [85, 100, 83, 112, 107, 114, 76, 105, 102, 116])
JNIBXY = "".join(
    chr(c) for c in [76, 101, 97, 114, 110, 80, 104, 97, 115, 101, 69, 114, 114]
)
JPUNRJ = "".join(chr(c) for c in [67, 70, 71, 49, 51])
JQRJJJ = "".join(chr(c) for c in [80, 97, 99, 107, 82, 101, 103, 105, 111, 110])
JRJHIU = "".join(chr(c) for c in [85, 100, 80, 51])
JTACCP = "".join(chr(c) for c in [70, 98])
JUGSEL = "".join(chr(c) for c in [67, 70, 71, 51])
JUIKFW = 270
JUTYEK = "".join(chr(c) for c in [85, 100, 86, 83, 80, 51])
JVDQLA = "".join(
    chr(c) for c in [82, 104, 82, 101, 103, 79, 118, 101, 114, 72, 101, 97, 116]
)
JVHFTH = 256
JVYFCR = 323
JWMNZM = 307
JYKLGQ = "".join(
    chr(c) for c in [69, 99, 111, 110, 111, 109, 121, 65, 99, 99, 101, 115, 115]
)
JYMOUN = 301
JZTATD = 463
KCWAON = "".join(chr(c) for c in [76, 79, 87])
KEAKST = 471
KFWRKI = "".join(chr(c) for c in [69, 99, 111, 110, 65, 99, 116, 105, 118, 101])
KINEJN = 277
KJPUNR = 460
KLGQPL = 313
KMLOIJ = 448
KPHUOJ = 2
KQXPIC = 300
KSOKPH = "".join(chr(c) for c in [72, 73])
KSTSEM = "".join(chr(c) for c in [67, 70, 71, 50, 53])
KVKZIL = "".join(chr(c) for c in [82, 104, 76, 111, 119, 70, 108, 111])
KWIVDN = "".join(
    chr(c) for c in [105, 110, 84, 104, 101, 114, 109, 67, 117, 114, 49, 75, 87]
)
KXSJWM = "".join(chr(c) for c in [82, 69, 77, 79, 84, 69])
KZILXW = 258
LAIIDN = "".join(chr(c) for c in [82, 104, 83, 87, 84, 114, 105, 97, 99, 79, 72])
LASSAK = "".join(chr(c) for c in [83, 116, 105, 99, 107, 66, 97, 110, 107])
LGQPLS = "".join(
    chr(c) for c in [82, 101, 109, 111, 116, 101, 69, 99, 111, 110, 68, 117, 114]
)
LHBQNR = 453
LIUXFE = "".join(chr(c) for c in [66, 76])
LJUIKF = "".join(chr(c) for c in [72, 101, 97, 116, 105, 110, 103])
LKXSJW = "".join(chr(c) for c in [73, 78, 84, 69, 82, 78, 65, 76])
LNMHXE = "".join(chr(c) for c in [114, 72, 73, 100])
LOIJUG = 449
LRAHEO = 292
LSPFTS = "".join(
    chr(c)
    for c in [82, 101, 109, 111, 116, 101, 78, 98, 79, 102, 80, 104, 97, 115, 101, 115]
)
LSXUJU = "".join(chr(c) for c in [77, 69, 68])
LXWAJV = "".join(
    chr(c) for c in [82, 104, 78, 111, 70, 108, 111, 88, 84, 114, 105, 101, 115]
)
MAOAWB = "".join(chr(c) for c in [83, 119, 109, 82, 105, 115, 107])
MCBFEG = "".join(chr(c) for c in [85, 100, 70, 98])
MCGETI = 475
MFZDGK = "".join(chr(c) for c in [67, 70, 71, 50, 49])
MHXEKV = "".join(chr(c) for c in [82, 104, 67, 111, 109, 109, 69, 114, 114])
MJIGYO = "".join(chr(c) for c in [65, 67, 84, 73, 86, 69])
MJMAOA = "".join(chr(c) for c in [83, 119, 109, 65, 99, 116, 105, 118, 101])
MJVHFT = "".join(chr(c) for c in [72, 111, 117, 114, 115])
MLOIJU = "".join(chr(c) for c in [67, 70, 71, 49])
MNHTBJ = 328
MNZMJI = "".join(chr(c) for c in [83, 84, 79, 80])
MOUNBL = 305
NBLKXS = "".join(
    chr(c) for c in [70, 105, 108, 116, 101, 114, 65, 99, 99, 101, 115, 115]
)
NEJNIB = "".join(
    chr(c)
    for c in [
        67,
        111,
        110,
        116,
        97,
        99,
        116,
        111,
        114,
        67,
        111,
        105,
        108,
        70,
        97,
        105,
        108,
        69,
        114,
        114,
    ]
)
NHTBJE = "".join(chr(c) for c in [80, 97, 99, 107, 67, 111, 110, 102, 73, 68])
NIBXTI = "".join(chr(c) for c in [82, 104, 72, 87, 75, 105, 110])
NIBXYB = "".join(chr(c) for c in [70, 117, 115, 101, 51, 69, 114, 114])
NKMLOI = "".join(chr(c) for c in [67, 70, 71, 48])
NMHXEK = "".join(chr(c) for c in [75, 105, 110, 80, 117, 109, 112, 79, 102, 102])
NPYYLI = 6
NQGVUN = 343
NQJYMO = 274
NQLNMH = "".join(
    chr(c) for c in [65, 109, 98, 105, 97, 110, 116, 79, 72, 76, 101, 118, 101, 108, 49]
)
NQTMFZ = 467
NRJZTA = 462
NRSJMC = 8
NRXCHW = 455
NXNKML = "".join(chr(c) for c in [75, 54, 48, 48, 80, 114, 111, 116, 111, 99, 111, 108])
NZMJIG = "".join(chr(c) for c in [83, 84, 65, 82, 84])
OAWBSI = "".join(chr(c) for c in [78, 79])
OCTHBS = "".join(chr(c) for c in [72, 101, 97, 116, 101, 114, 82, 101, 97, 100])
OIHBXI = "".join(chr(c) for c in [76, 73])
OIJUGS = "".join(chr(c) for c in [67, 70, 71, 50])
OJRJHI = 12
OKPHUO = 14
ONPYYL = "".join(chr(c) for c in [80, 52])
OOQNRS = "".join(chr(c) for c in [85, 100, 66, 76])
OPHUGT = "".join(chr(c) for c in [80, 97, 99, 107, 76, 111, 103, 84, 114, 105, 103])
OQNRSJ = "".join(chr(c) for c in [79, 78])
OUNBLK = "".join(chr(c) for c in [86, 83, 80, 51, 70, 114, 111, 110, 116])
OUSPBW = 316
OUYNQJ = "".join(chr(c) for c in [83, 97, 110, 105])
PBWJYK = 310
PFTSIF = "".join(
    chr(c)
    for c in [
        82,
        101,
        109,
        111,
        116,
        101,
        66,
        114,
        101,
        97,
        107,
        101,
        114,
        73,
        110,
        100,
        101,
        120,
    ]
)
PHUGTY = 357
PHUOJR = 4
PICXQI = "".join(chr(c) for c in [79, 85, 84, 49, 66, 82, 101, 97, 100])
PIPIVL = "".join(chr(c) for c in [76, 101, 97, 114, 110, 70, 97, 105, 108])
PIVLAS = "".join(
    chr(c) for c in [66, 114, 101, 97, 107, 101, 114, 83, 101, 108, 101, 99, 116]
)
PLSPFT = 350
POUYNQ = "".join(chr(c) for c in [83, 112, 107, 114, 76, 105, 102, 116])
PQIPOU = "".join(chr(c) for c in [68, 79, 87, 78])
PUNRJZ = 461
PYYLIU = "".join(chr(c) for c in [80, 53])
QBMJVH = "".join(chr(c) for c in [82, 104, 84, 114, 105, 97, 99, 84, 101, 109, 112])
QEXLSX = 0
QFFTTI = 317
QFYLJU = 349
QGLRAH = 290
QGVUNX = "".join(chr(c) for c in [75, 54, 48, 48, 82, 101, 118])
QIEFXQ = "".join(chr(c) for c in [79, 85, 84, 50, 66, 82, 101, 97, 100])
QIPOUY = "".join(chr(c) for c in [85, 80])
QJYMOU = "".join(chr(c) for c in [86, 115, 112, 49, 70, 114, 111, 110, 116])
QLAIID = "".join(chr(c) for c in [82, 104, 72, 114, 84, 114, 105, 97, 99, 79, 72])
QLNMHX = "".join(chr(c) for c in [82, 101, 108, 97, 121, 83, 116, 117, 99, 107])
QNRXCH = "".join(chr(c) for c in [67, 70, 71, 55])
QPLSPF = "".join(
    chr(c)
    for c in [
        82,
        101,
        109,
        111,
        116,
        101,
        67,
        111,
        110,
        102,
        105,
        103,
        73,
        110,
        100,
        101,
        120,
    ]
)
QRJJJV = "".join(chr(c) for c in [85, 76])
QSNQLN = "".join(chr(c) for c in [82, 101, 103, 79, 118, 101, 114, 72, 101, 97, 116])
QTMFZD = "".join(chr(c) for c in [67, 70, 71, 50, 48])
QVXOIH = "".join(chr(c) for c in [67, 70, 71, 51, 49])
QXPICX = "".join(chr(c) for c in [79, 85, 84, 49, 65, 82, 101, 97, 100])
RAHEOC = "".join(chr(c) for c in [79, 85, 84, 54, 65, 82, 101, 97, 100])
RJJJVY = "".join(chr(c) for c in [67, 69])
RJZTAT = "".join(chr(c) for c in [67, 70, 71, 49, 53])
RKINEJ = "".join(
    chr(c) for c in [70, 114, 101, 113, 68, 101, 116, 101, 99, 69, 114, 114]
)
RSJMCB = "".join(chr(c) for c in [85, 100, 84, 118, 76, 105, 102, 116])
RTFMNH = "".join(chr(c) for c in [80, 97, 99, 107, 67, 111, 114, 101, 82, 101, 118])
RXCHWD = "".join(chr(c) for c in [67, 70, 71, 56])
RYXBQF = 272
SBDJQR = "".join(chr(c) for c in [52, 56, 75])
SELHBQ = 452
SEMCGE = 474
SIFJBI = 269
SIRYXB = "".join(
    chr(c) for c in [83, 119, 109, 80, 117, 114, 103, 101, 83, 117, 115, 112]
)
SJMCBF = 5
SJWMNZ = "".join(
    chr(c)
    for c in [
        82,
        101,
        109,
        111,
        116,
        101,
        70,
        105,
        108,
        116,
        65,
        99,
        116,
        105,
        111,
        110,
    ]
)
SKSOKP = "".join(chr(c) for c in [76, 79])
SKWIVD = 338
SNQLNM = "".join(
    chr(c) for c in [65, 109, 98, 105, 97, 110, 116, 79, 72, 76, 101, 118, 101, 108, 50]
)
SOOQNR = 9
SPBWJY = "".join(
    chr(c)
    for c in [
        82,
        101,
        109,
        111,
        116,
        101,
        79,
        110,
        122,
        101,
        110,
        65,
        99,
        116,
        105,
        111,
        110,
    ]
)
SPFTSI = 351
SSAKQX = "".join(chr(c) for c in [80, 111, 119, 101, 114, 117, 112])
SSUHBV = "".join(chr(c) for c in [77, 97, 115, 73, 66, 67])
STSEMC = 473
SUHBVW = "".join(chr(c) for c in [77, 73, 65])
TACCPQ = 354
TATDZX = 464
TBJEUT = "".join(chr(c) for c in [80, 97, 99, 107, 67, 111, 110, 102, 82, 101, 118])
TDZXNQ = 465
TFMNHT = 327
THBSKS = "".join(chr(c) for c in [85, 100, 80, 49])
THECVY = "".join(chr(c) for c in [83, 49])
TIACQF = "".join(chr(c) for c in [82, 104, 70, 108, 111, 67, 104, 101, 99, 107])
TIDUBS = 320
TIXQVX = 477
TMFZDG = 468
TOPHUG = 333
TSEMCG = "".join(chr(c) for c in [67, 70, 71, 50, 54])
TSIFJB = "".join(chr(c) for c in [80, 117, 114, 103, 101])
TTIDUB = "".join(chr(c) for c in [80, 97, 99, 107, 66, 111, 111, 116, 82, 101, 108])
TYEKCW = "".join(chr(c) for c in [80, 49])
TYIYWS = "".join(chr(c) for c in [105, 110, 84, 104, 101, 114, 109, 73, 68])
UBSSUH = "".join(chr(c) for c in [85, 110, 107, 110, 111, 119, 110])
UGSELH = 451
UGTYIY = "".join(chr(c) for c in [70, 117, 108, 108])
UHBVWV = "".join(chr(c) for c in [68, 74, 83, 52])
UIKFWR = "".join(chr(c) for c in [67, 111, 111, 108, 105, 110, 103, 68, 111, 119, 110])
UJUTYE = 303
UNBLKX = 302
UNRJZT = "".join(chr(c) for c in [67, 70, 71, 49, 52])
UNXNKM = 346
UOJRJH = "".join(chr(c) for c in [85, 100, 80, 50])
UQEXLS = "".join(chr(c) for c in [85, 100, 81, 117, 105, 101, 116])
USOOQN = "".join(chr(c) for c in [85, 100, 80, 53])
USPBWJ = "".join(chr(c) for c in [79, 110, 122, 101, 110, 65, 99, 99, 101, 115, 115])
UTOPHU = "".join(
    chr(c)
    for c in [80, 97, 99, 107, 78, 117, 109, 98, 101, 114, 79, 102, 67, 111, 110, 102]
)
UTYEKC = 304
UXFEFJ = "".join(chr(c) for c in [79, 51])
UYNQJY = "".join(chr(c) for c in [79, 110, 122, 101, 110])
VDNQGV = 341
VDQLAI = "".join(chr(c) for c in [82, 104, 72, 114, 84, 114, 105, 97, 99, 80, 114])
VHFTHE = "".join(chr(c) for c in [77, 101, 110, 117])
VKZILX = "".join(chr(c) for c in [82, 104, 68, 117, 116, 121, 69, 114, 114])
VLASSA = "".join(
    chr(c) for c in [67, 111, 110, 102, 105, 103, 83, 101, 108, 101, 99, 116]
)
VUBYGD = "".join(chr(c) for c in [105, 110, 84, 111, 117, 99, 104])
VUNXNK = "".join(chr(c) for c in [75, 54, 48, 48, 82, 101, 108])
VWVUBY = "".join(chr(c) for c in [75, 54, 48, 48])
VXOIHB = 479
VYFCRT = "".join(
    chr(c) for c in [80, 97, 99, 107, 67, 111, 110, 102, 105, 103, 76, 105, 98]
)
VYYPIP = "".join(chr(c) for c in [72, 51])
WAJVDQ = "".join(chr(c) for c in [82, 104, 72, 119, 72, 76])
WAONPY = "".join(chr(c) for c in [80, 50])
WDAFIK = "".join(chr(c) for c in [67, 70, 71, 49, 48])
WIVDNQ = 339
WJYKLG = 311
WMNZMJ = "".join(chr(c) for c in [73, 68, 76, 69])
WRKINE = "".join(
    chr(c) for c in [80, 114, 111, 103, 69, 99, 111, 110, 65, 99, 116, 105, 118, 101]
)
WSKWIV = "".join(chr(c) for c in [105, 110, 84, 104, 101, 114, 109, 82, 101, 108])
WVUBYG = "".join(chr(c) for c in [105, 110, 84, 101, 114, 102, 97, 99, 101])
XBQFYL = 265
XCHWDA = 456
XEKVKZ = "".join(
    chr(c)
    for c in [82, 104, 78, 111, 116, 69, 110, 111, 117, 103, 104, 72, 101, 97, 116]
)
XFEFJT = 3
XIBHZV = 479
XLSXUJ = 306
XNKMLO = 347
XNQTMF = "".join(chr(c) for c in [67, 70, 71, 49, 57])
XPICXQ = 280
XQGLRA = "".join(chr(c) for c in [79, 85, 84, 52, 65, 82, 101, 97, 100])
XQIEFX = 284
XQVXOI = 478
XTIACQ = "".join(
    chr(c) for c in [82, 104, 70, 108, 111, 68, 101, 116, 101, 99, 116, 101, 100]
)
XUJUTY = "".join(chr(c) for c in [85, 100, 86, 83, 80, 49])
XWAJVD = "".join(chr(c) for c in [82, 104, 72, 114, 72, 76])
XYBQSN = 278
YBQSNQ = "".join(chr(c) for c in [83, 117, 112, 112, 108, 121, 69, 114, 114])
YEKCWA = 356
YFCRTF = 324
YGDSBD = 322
YIYWSK = 335
YKLGQP = "".join(
    chr(c)
    for c in [82, 101, 109, 111, 116, 101, 69, 99, 111, 110, 65, 99, 116, 105, 111, 110]
)
YLJUIK = "".join(chr(c) for c in [67, 104, 101, 99, 107, 70, 108, 111])
YMOUNB = "".join(chr(c) for c in [86, 115, 112, 49, 77, 105, 110])
YNQJYM = "".join(chr(c) for c in [82, 104, 68, 117, 116, 121])
YOUSPB = "".join(
    chr(c)
    for c in [
        82,
        101,
        109,
        111,
        116,
        101,
        70,
        105,
        108,
        116,
        68,
        117,
        114,
        80,
        101,
        114,
        68,
        97,
        121,
    ]
)
YPIPIV = "".join(chr(c) for c in [70, 114])
YWSKWI = 337
YXBQFY = "".join(
    chr(c) for c in [68, 105, 115, 112, 108, 97, 121, 101, 100, 84, 101, 109, 112, 71]
)
YYLIUX = 355
YYPIPI = "".join(chr(c) for c in [72, 52])
ZCQBMJ = "".join(chr(c) for c in [82, 104, 87, 97, 116, 101, 114, 84, 101, 109, 112])
ZDGKEA = "".join(chr(c) for c in [67, 70, 71, 50, 50])
ZILXWA = "".join(
    chr(c) for c in [82, 104, 78, 111, 70, 108, 111, 82, 101, 116, 114, 121]
)
ZMJIGY = "".join(chr(c) for c in [78, 69, 87])
ZTATDZ = "".join(chr(c) for c in [67, 70, 71, 49, 54])
ZUQEXL = 1
ZXNQTM = 466
ACCPQI = [BSKSOK, BSKSOK, CBFEGZ, FEGZUQ]
CWAONP = [BSKSOK, EKCWAO, KCWAON]
DJQRJJ = [GDSBDJ, DSBDJQ, SBDJQR, BDJQRJ]
EGZUQE = [BSKSOK, CBFEGZ, BFEGZU, FEGZUQ]
GTYIYW = [HUGTYI, UGTYIY]
HBXIBH = [
    THBSKS,
    UOJRJH,
    JRJHIU,
    HIUSOO,
    USOOQN,
    OOQNRS,
    RSJMCB,
    JMCBFE,
    MCBFEG,
    GZUQEX,
    UQEXLS,
    EXLSXU,
    XUJUTY,
    JUTYEK,
]
IHBXIB = [
    TYEKCW,
    WAONPY,
    AONPYY,
    ONPYYL,
    PYYLIU,
    LIUXFE,
    IUXFEF,
    UXFEFJ,
    FEFJTA,
    EFJTAC,
    JTACCP,
    CCPQIP,
    CPQIPO,
    POUYNQ,
    OUYNQJ,
    UYNQJY,
    YNQJYM,
    QJYMOU,
    YMOUNB,
    OUNBLK,
    OIHBXI,
]
IPOUYN = [PQIPOU, QIPOUY]
JIGYOU = [WMNZMJ, MNZMJI, NZMJIG, ZMJIGY, MJIGYO]
JJJVYF = [QRJJJV, RJJJVY]
QNRSJM = [BSKSOK, OQNRSJ]
RJHIUS = [BSKSOK, KSOKPH]
SAKQXP = [
    FTHECV,
    THECVY,
    HECVYY,
    ECVYYP,
    CVYYPI,
    VYYPIP,
    YYPIPI,
    YPIPIV,
    PIPIVL,
    IPIVLA,
    PIVLAS,
    IVLASS,
    VLASSA,
    LASSAK,
    ASSAKQ,
    SSAKQX,
]
SOKPHU = [BSKSOK, SKSOKP, KSOKPH]
SXUJUT = [BSKSOK, SKSOKP, LSXUJU, KSOKPH]
UBYGDS = [
    UBSSUH,
    BSSUHB,
    SSUHBV,
    SUHBVW,
    UHBVWV,
    HBVWVU,
    BVWVUB,
    VWVUBY,
    WVUBYG,
    VUBYGD,
]
WBSIRY = [OAWBSI, SKSOKP, LSXUJU, KSOKPH, AWBSIR]
XOIHBX = []
XSJWMN = [LKXSJW, KXSJWM]
YLIUXF = [BSKSOK, EKCWAO]


class GeckoLogStruct:
    def __init__(self, struct_):
        self.struct = struct_

    @property
    def version(self):
        return PHUOJR

    @property
    def begin(self):
        return BXIBHZ

    @property
    def end(self):
        return XIBHZV

    @property
    def all_device_keys(self):
        return IHBXIB

    @property
    def user_demand_keys(self):
        return HBXIBH

    @property
    def accessors(self):
        return {
            ZCQBMJ: GeckoTempStructAccessor(self.struct, ZCQBMJ, CQBMJV, None),
            QBMJVH: GeckoTempStructAccessor(self.struct, QBMJVH, BMJVHF, None),
            MJVHFT: GeckoByteStructAccessor(self.struct, MJVHFT, JVHFTH, None),
            VHFTHE: GeckoEnumStructAccessor(
                self.struct, VHFTHE, HFTHEC, None, SAKQXP, None, None, None
            ),
            AKQXPI: GeckoByteStructAccessor(self.struct, AKQXPI, KQXPIC, None),
            QXPICX: GeckoWordStructAccessor(self.struct, QXPICX, XPICXQ, None),
            PICXQI: GeckoWordStructAccessor(self.struct, PICXQI, ICXQIE, None),
            CXQIEF: GeckoWordStructAccessor(self.struct, CXQIEF, XQIEFX, None),
            QIEFXQ: GeckoWordStructAccessor(self.struct, QIEFXQ, IEFXQG, None),
            EFXQGL: GeckoWordStructAccessor(self.struct, EFXQGL, FXQGLR, None),
            XQGLRA: GeckoWordStructAccessor(self.struct, XQGLRA, QGLRAH, None),
            GLRAHE: GeckoWordStructAccessor(self.struct, GLRAHE, LRAHEO, None),
            RAHEOC: GeckoWordStructAccessor(self.struct, RAHEOC, AHEOCT, None),
            HEOCTH: GeckoWordStructAccessor(self.struct, HEOCTH, EOCTHB, None),
            OCTHBS: GeckoWordStructAccessor(self.struct, OCTHBS, CTHBSK, None),
            THBSKS: GeckoEnumStructAccessor(
                self.struct, THBSKS, HBSKSO, OKPHUO, SOKPHU, KPHUOJ, PHUOJR, HUOJRJ
            ),
            UOJRJH: GeckoEnumStructAccessor(
                self.struct, UOJRJH, HBSKSO, OJRJHI, SOKPHU, KPHUOJ, PHUOJR, HUOJRJ
            ),
            JRJHIU: GeckoEnumStructAccessor(
                self.struct, JRJHIU, HBSKSO, JHIUSO, RJHIUS, KPHUOJ, KPHUOJ, HUOJRJ
            ),
            HIUSOO: GeckoEnumStructAccessor(
                self.struct, HIUSOO, HBSKSO, IUSOOQ, RJHIUS, KPHUOJ, KPHUOJ, HUOJRJ
            ),
            USOOQN: GeckoEnumStructAccessor(
                self.struct, USOOQN, HBSKSO, SOOQNR, RJHIUS, KPHUOJ, KPHUOJ, HUOJRJ
            ),
            OOQNRS: GeckoEnumStructAccessor(
                self.struct, OOQNRS, HBSKSO, NRSJMC, QNRSJM, KPHUOJ, KPHUOJ, HUOJRJ
            ),
            RSJMCB: GeckoEnumStructAccessor(
                self.struct, RSJMCB, HBSKSO, SJMCBF, QNRSJM, KPHUOJ, KPHUOJ, HUOJRJ
            ),
            JMCBFE: GeckoEnumStructAccessor(
                self.struct, JMCBFE, HBSKSO, PHUOJR, QNRSJM, KPHUOJ, KPHUOJ, HUOJRJ
            ),
            MCBFEG: GeckoEnumStructAccessor(
                self.struct, MCBFEG, HBSKSO, KPHUOJ, EGZUQE, KPHUOJ, PHUOJR, HUOJRJ
            ),
            GZUQEX: GeckoEnumStructAccessor(
                self.struct, GZUQEX, HBSKSO, ZUQEXL, QNRSJM, KPHUOJ, KPHUOJ, HUOJRJ
            ),
            UQEXLS: GeckoBoolStructAccessor(
                self.struct, UQEXLS, HBSKSO, QEXLSX, HUOJRJ
            ),
            EXLSXU: GeckoEnumStructAccessor(
                self.struct, EXLSXU, XLSXUJ, QEXLSX, SXUJUT, None, PHUOJR, HUOJRJ
            ),
            XUJUTY: GeckoByteStructAccessor(self.struct, XUJUTY, UJUTYE, HUOJRJ),
            JUTYEK: GeckoByteStructAccessor(self.struct, JUTYEK, UTYEKC, HUOJRJ),
            TYEKCW: GeckoEnumStructAccessor(
                self.struct, TYEKCW, YEKCWA, QEXLSX, CWAONP, None, PHUOJR, None
            ),
            WAONPY: GeckoEnumStructAccessor(
                self.struct, WAONPY, YEKCWA, KPHUOJ, CWAONP, None, PHUOJR, None
            ),
            AONPYY: GeckoEnumStructAccessor(
                self.struct, AONPYY, YEKCWA, PHUOJR, CWAONP, None, PHUOJR, None
            ),
            ONPYYL: GeckoEnumStructAccessor(
                self.struct, ONPYYL, YEKCWA, NPYYLI, CWAONP, None, PHUOJR, None
            ),
            PYYLIU: GeckoEnumStructAccessor(
                self.struct, PYYLIU, YYLIUX, QEXLSX, YLIUXF, None, KPHUOJ, None
            ),
            LIUXFE: GeckoEnumStructAccessor(
                self.struct, LIUXFE, YYLIUX, ZUQEXL, QNRSJM, None, KPHUOJ, None
            ),
            IUXFEF: GeckoEnumStructAccessor(
                self.struct, IUXFEF, YYLIUX, KPHUOJ, QNRSJM, None, KPHUOJ, None
            ),
            UXFEFJ: GeckoEnumStructAccessor(
                self.struct, UXFEFJ, YYLIUX, XFEFJT, QNRSJM, None, KPHUOJ, None
            ),
            FEFJTA: GeckoEnumStructAccessor(
                self.struct, FEFJTA, YYLIUX, PHUOJR, QNRSJM, None, KPHUOJ, None
            ),
            EFJTAC: GeckoEnumStructAccessor(
                self.struct, EFJTAC, YYLIUX, FJTACC, QNRSJM, None, KPHUOJ, None
            ),
            JTACCP: GeckoEnumStructAccessor(
                self.struct, JTACCP, TACCPQ, QEXLSX, ACCPQI, None, PHUOJR, None
            ),
            CCPQIP: GeckoEnumStructAccessor(
                self.struct, CCPQIP, TACCPQ, KPHUOJ, QNRSJM, None, KPHUOJ, None
            ),
            CPQIPO: GeckoEnumStructAccessor(
                self.struct, CPQIPO, TACCPQ, XFEFJT, IPOUYN, None, KPHUOJ, None
            ),
            POUYNQ: GeckoEnumStructAccessor(
                self.struct, POUYNQ, TACCPQ, PHUOJR, IPOUYN, None, KPHUOJ, None
            ),
            OUYNQJ: GeckoEnumStructAccessor(
                self.struct, OUYNQJ, TACCPQ, SJMCBF, QNRSJM, None, KPHUOJ, None
            ),
            UYNQJY: GeckoEnumStructAccessor(
                self.struct, UYNQJY, TACCPQ, NPYYLI, QNRSJM, None, KPHUOJ, None
            ),
            YNQJYM: GeckoByteStructAccessor(self.struct, YNQJYM, NQJYMO, None),
            QJYMOU: GeckoByteStructAccessor(self.struct, QJYMOU, JYMOUN, None),
            YMOUNB: GeckoByteStructAccessor(self.struct, YMOUNB, MOUNBL, None),
            OUNBLK: GeckoByteStructAccessor(self.struct, OUNBLK, UNBLKX, None),
            NBLKXS: GeckoEnumStructAccessor(
                self.struct, NBLKXS, BLKXSJ, QEXLSX, XSJWMN, None, KPHUOJ, HUOJRJ
            ),
            SJWMNZ: GeckoEnumStructAccessor(
                self.struct, SJWMNZ, JWMNZM, None, JIGYOU, None, None, HUOJRJ
            ),
            IGYOUS: GeckoTimeStructAccessor(self.struct, IGYOUS, GYOUSP, HUOJRJ),
            YOUSPB: GeckoByteStructAccessor(self.struct, YOUSPB, OUSPBW, HUOJRJ),
            USPBWJ: GeckoEnumStructAccessor(
                self.struct, USPBWJ, BLKXSJ, ZUQEXL, XSJWMN, None, KPHUOJ, HUOJRJ
            ),
            SPBWJY: GeckoEnumStructAccessor(
                self.struct, SPBWJY, PBWJYK, None, JIGYOU, None, None, HUOJRJ
            ),
            BWJYKL: GeckoTimeStructAccessor(self.struct, BWJYKL, WJYKLG, HUOJRJ),
            JYKLGQ: GeckoEnumStructAccessor(
                self.struct, JYKLGQ, BLKXSJ, KPHUOJ, XSJWMN, None, KPHUOJ, HUOJRJ
            ),
            YKLGQP: GeckoEnumStructAccessor(
                self.struct, YKLGQP, KLGQPL, None, JIGYOU, None, None, HUOJRJ
            ),
            LGQPLS: GeckoTimeStructAccessor(self.struct, LGQPLS, GQPLSP, HUOJRJ),
            QPLSPF: GeckoByteStructAccessor(self.struct, QPLSPF, PLSPFT, HUOJRJ),
            LSPFTS: GeckoByteStructAccessor(self.struct, LSPFTS, SPFTSI, HUOJRJ),
            PFTSIF: GeckoByteStructAccessor(self.struct, PFTSIF, FTSIFJ, HUOJRJ),
            TSIFJB: GeckoBoolStructAccessor(self.struct, TSIFJB, SIFJBI, FJTACC, None),
            IFJBIA: GeckoBoolStructAccessor(self.struct, IFJBIA, SIFJBI, SJMCBF, None),
            FJBIAM: GeckoBoolStructAccessor(self.struct, FJBIAM, SIFJBI, PHUOJR, None),
            JBIAMJ: GeckoBoolStructAccessor(self.struct, JBIAMJ, BIAMJM, XFEFJT, None),
            IAMJMA: GeckoBoolStructAccessor(self.struct, IAMJMA, BIAMJM, QEXLSX, None),
            AMJMAO: GeckoBoolStructAccessor(self.struct, AMJMAO, BIAMJM, ZUQEXL, None),
            MJMAOA: GeckoBoolStructAccessor(self.struct, MJMAOA, JMAOAW, None, None),
            MAOAWB: GeckoEnumStructAccessor(
                self.struct, MAOAWB, AOAWBS, None, WBSIRY, None, None, None
            ),
            BSIRYX: GeckoBoolStructAccessor(self.struct, BSIRYX, SIFJBI, XFEFJT, None),
            SIRYXB: GeckoBoolStructAccessor(self.struct, SIRYXB, SIFJBI, KPHUOJ, None),
            IRYXBQ: GeckoTempStructAccessor(self.struct, IRYXBQ, RYXBQF, None),
            YXBQFY: GeckoTempStructAccessor(self.struct, YXBQFY, XBQFYL, None),
            BQFYLJ: GeckoBoolStructAccessor(self.struct, BQFYLJ, QFYLJU, ZUQEXL, None),
            FYLJUI: GeckoBoolStructAccessor(self.struct, FYLJUI, SIFJBI, ZUQEXL, None),
            YLJUIK: GeckoBoolStructAccessor(self.struct, YLJUIK, SIFJBI, QEXLSX, None),
            LJUIKF: GeckoBoolStructAccessor(self.struct, LJUIKF, JUIKFW, FJTACC, None),
            UIKFWR: GeckoBoolStructAccessor(self.struct, UIKFWR, JUIKFW, NPYYLI, None),
            IKFWRK: GeckoBoolStructAccessor(self.struct, IKFWRK, JUIKFW, SJMCBF, None),
            KFWRKI: GeckoBoolStructAccessor(self.struct, KFWRKI, FWRKIN, QEXLSX, None),
            WRKINE: GeckoBoolStructAccessor(self.struct, WRKINE, FWRKIN, KPHUOJ, None),
            RKINEJ: GeckoBoolStructAccessor(self.struct, RKINEJ, KINEJN, NPYYLI, None),
            INEJNI: GeckoBoolStructAccessor(self.struct, INEJNI, KINEJN, SJMCBF, None),
            NEJNIB: GeckoBoolStructAccessor(self.struct, NEJNIB, KINEJN, PHUOJR, None),
            EJNIBX: GeckoBoolStructAccessor(self.struct, EJNIBX, KINEJN, XFEFJT, None),
            JNIBXY: GeckoBoolStructAccessor(self.struct, JNIBXY, KINEJN, KPHUOJ, None),
            NIBXYB: GeckoBoolStructAccessor(self.struct, NIBXYB, KINEJN, ZUQEXL, None),
            IBXYBQ: GeckoBoolStructAccessor(self.struct, IBXYBQ, KINEJN, QEXLSX, None),
            BXYBQS: GeckoBoolStructAccessor(self.struct, BXYBQS, XYBQSN, FJTACC, None),
            YBQSNQ: GeckoBoolStructAccessor(self.struct, YBQSNQ, XYBQSN, NPYYLI, None),
            BQSNQL: GeckoBoolStructAccessor(self.struct, BQSNQL, XYBQSN, SJMCBF, None),
            QSNQLN: GeckoBoolStructAccessor(self.struct, QSNQLN, XYBQSN, PHUOJR, None),
            SNQLNM: GeckoBoolStructAccessor(self.struct, SNQLNM, XYBQSN, XFEFJT, None),
            NQLNMH: GeckoBoolStructAccessor(self.struct, NQLNMH, XYBQSN, KPHUOJ, None),
            QLNMHX: GeckoBoolStructAccessor(self.struct, QLNMHX, XYBQSN, ZUQEXL, None),
            LNMHXE: GeckoBoolStructAccessor(self.struct, LNMHXE, XYBQSN, QEXLSX, None),
            NMHXEK: GeckoBoolStructAccessor(self.struct, NMHXEK, BIAMJM, PHUOJR, None),
            MHXEKV: GeckoBoolStructAccessor(self.struct, MHXEKV, HXEKVK, FJTACC, None),
            XEKVKZ: GeckoBoolStructAccessor(self.struct, XEKVKZ, HXEKVK, XFEFJT, None),
            EKVKZI: GeckoBoolStructAccessor(self.struct, EKVKZI, HXEKVK, KPHUOJ, None),
            KVKZIL: GeckoBoolStructAccessor(self.struct, KVKZIL, HXEKVK, QEXLSX, None),
            VKZILX: GeckoBoolStructAccessor(self.struct, VKZILX, KZILXW, FJTACC, None),
            ZILXWA: GeckoBoolStructAccessor(self.struct, ZILXWA, KZILXW, NPYYLI, None),
            ILXWAJ: GeckoBoolStructAccessor(self.struct, ILXWAJ, KZILXW, SJMCBF, None),
            LXWAJV: GeckoBoolStructAccessor(self.struct, LXWAJV, KZILXW, PHUOJR, None),
            XWAJVD: GeckoBoolStructAccessor(self.struct, XWAJVD, KZILXW, XFEFJT, None),
            WAJVDQ: GeckoBoolStructAccessor(self.struct, WAJVDQ, KZILXW, KPHUOJ, None),
            AJVDQL: GeckoBoolStructAccessor(self.struct, AJVDQL, KZILXW, ZUQEXL, None),
            JVDQLA: GeckoBoolStructAccessor(self.struct, JVDQLA, KZILXW, QEXLSX, None),
            VDQLAI: GeckoBoolStructAccessor(self.struct, VDQLAI, DQLAII, FJTACC, None),
            QLAIID: GeckoBoolStructAccessor(self.struct, QLAIID, DQLAII, NPYYLI, None),
            LAIIDN: GeckoBoolStructAccessor(self.struct, LAIIDN, DQLAII, SJMCBF, None),
            AIIDNI: GeckoBoolStructAccessor(self.struct, AIIDNI, DQLAII, PHUOJR, None),
            IIDNIB: GeckoBoolStructAccessor(self.struct, IIDNIB, DQLAII, XFEFJT, None),
            IDNIBX: GeckoBoolStructAccessor(self.struct, IDNIBX, DQLAII, KPHUOJ, None),
            DNIBXT: GeckoBoolStructAccessor(self.struct, DNIBXT, DQLAII, ZUQEXL, None),
            NIBXTI: GeckoBoolStructAccessor(self.struct, NIBXTI, DQLAII, QEXLSX, None),
            IBXTIA: GeckoBoolStructAccessor(self.struct, IBXTIA, BXTIAC, PHUOJR, None),
            XTIACQ: GeckoBoolStructAccessor(self.struct, XTIACQ, BXTIAC, XFEFJT, None),
            TIACQF: GeckoBoolStructAccessor(self.struct, TIACQF, BXTIAC, KPHUOJ, None),
            IACQFF: GeckoBoolStructAccessor(self.struct, IACQFF, BXTIAC, ZUQEXL, None),
            ACQFFT: GeckoBoolStructAccessor(self.struct, ACQFFT, BXTIAC, QEXLSX, None),
            CQFFTT: GeckoWordStructAccessor(self.struct, CQFFTT, QFFTTI, None),
            FFTTID: GeckoByteStructAccessor(self.struct, FFTTID, FTTIDU, None),
            TTIDUB: GeckoByteStructAccessor(self.struct, TTIDUB, TIDUBS, None),
            IDUBSS: GeckoEnumStructAccessor(
                self.struct, IDUBSS, DUBSSU, None, UBYGDS, None, None, None
            ),
            BYGDSB: GeckoEnumStructAccessor(
                self.struct, BYGDSB, YGDSBD, QEXLSX, DJQRJJ, None, PHUOJR, None
            ),
            JQRJJJ: GeckoEnumStructAccessor(
                self.struct, JQRJJJ, YGDSBD, KPHUOJ, JJJVYF, None, KPHUOJ, None
            ),
            JJVYFC: GeckoByteStructAccessor(self.struct, JJVYFC, JVYFCR, None),
            VYFCRT: GeckoByteStructAccessor(self.struct, VYFCRT, YFCRTF, None),
            FCRTFM: GeckoWordStructAccessor(self.struct, FCRTFM, CRTFMN, None),
            RTFMNH: GeckoByteStructAccessor(self.struct, RTFMNH, TFMNHT, None),
            FMNHTB: GeckoByteStructAccessor(self.struct, FMNHTB, MNHTBJ, None),
            NHTBJE: GeckoWordStructAccessor(self.struct, NHTBJE, HTBJEU, None),
            TBJEUT: GeckoByteStructAccessor(self.struct, TBJEUT, BJEUTO, None),
            JEUTOP: GeckoByteStructAccessor(self.struct, JEUTOP, EUTOPH, None),
            UTOPHU: GeckoWordStructAccessor(self.struct, UTOPHU, TOPHUG, None),
            OPHUGT: GeckoEnumStructAccessor(
                self.struct, OPHUGT, PHUGTY, None, GTYIYW, None, KPHUOJ, HUOJRJ
            ),
            TYIYWS: GeckoWordStructAccessor(self.struct, TYIYWS, YIYWSK, None),
            IYWSKW: GeckoByteStructAccessor(self.struct, IYWSKW, YWSKWI, None),
            WSKWIV: GeckoByteStructAccessor(self.struct, WSKWIV, SKWIVD, None),
            KWIVDN: GeckoWordStructAccessor(self.struct, KWIVDN, WIVDNQ, None),
            IVDNQG: GeckoWordStructAccessor(self.struct, IVDNQG, VDNQGV, None),
        }



""" GeckoAsyncUdpProtocol - Gecko Async UDP protocol implementation """

import asyncio
import logging

from .udp_protocol_handler import GeckoUdpProtocolHandler
from .async_peekablequeue import AsyncPeekableQueue
from typing import Optional, Callable, TypeVar

_LOGGER = logging.getLogger(__name__)


class GeckoAsyncUdpProtocol(asyncio.DatagramProtocol):
    """Gecko in.touch2 uses UDP to communicate. This class is an async
    UDP protocol handler for asyncio. It dispatches to classes derived
    from GeckoUdpProtocolHandler. Since it doesn't need to be thread safe
    it's a good deal more simple that its predecessor
    """

    def __init__(self, on_connection_lost, destination) -> None:
        self.transport = None
        self._on_connection_lost = on_connection_lost
        self._destination = destination

        self._sequence_counter = 0
        self._queue = AsyncPeekableQueue()
        self._lock = asyncio.Lock()

    @property
    def Lock(self):
        return self._lock

    def connection_made(self, transport) -> None:
        _LOGGER.debug("GeckoAsyncUdpProtocol: connection made to %s", transport)
        self.transport = transport

    def connection_lost(self, exc) -> None:
        _LOGGER.debug(
            "GeckoAsyncUdpProtocol: connection lost from %s (%s)", self.transport, exc
        )
        self.transport = None
        if self._on_connection_lost is not None:
            self._on_connection_lost.set_result(True)

    def error_received(self, exc) -> None:
        _LOGGER.exception("GeckoAsyncUdpProtocol: Exception received %s", exc)
        # TODO: What do we want to do with this?

    @property
    def isopen(self) -> bool:
        """Check to see if the transport is connected"""
        return self.transport is not None

    def disconnect(self) -> None:
        self.connection_lost(None)

    @property
    def queue(self) -> AsyncPeekableQueue:
        return self._queue

    def queue_send(
        self, protocol_handler: GeckoUdpProtocolHandler, destination=None
    ) -> None:
        """Queue a message to be sent async later"""
        if not self.isopen:
            _LOGGER.warning("Cannot queue message as transport is closed")
            return
        assert self.transport is not None
        if destination is None:
            destination = self._destination
        protocol_handler.last_destination = destination

        send_bytes = protocol_handler.send_bytes
        _LOGGER.debug("Sending %s to %s", send_bytes, destination)
        self.transport.sendto(send_bytes, destination)

    def get_and_increment_sequence_counter(self) -> int:
        self._sequence_counter += 1
        return self._sequence_counter % 256

    def datagram_received(self, data, addr) -> None:
        _LOGGER.debug("Received %s from %s", data, addr)
        self.queue.put_nowait((data, addr))

    T = TypeVar("T", bound="GeckoUdpProtocolHandler")

    async def get(
        self,
        create_func: Callable[[], T],
        destination: Optional[tuple] = None,
        retry_count: int = 10,
    ) -> Optional[T]:

        _LOGGER.debug("Async get started, acquire the lock")
        async with self.Lock:
            _LOGGER.debug("Lock acquired")

            while retry_count > 0:

                # Create the request
                request = create_func()
                # Queue it for delivery
                self.queue_send(request, destination)

                # Wait for a response up to a certain amount of time
                if await request.wait_for_response(self):
                    # If handled, then return the handler which ought
                    # to contain the information as requested
                    return request

                # Loop for retry
                retry_count -= 1

            return None

    def __repr__(self) -> str:
        return (
            f"{self.__class__.__name__} on {self.transport!r}\n"
            f" isopen: {self.isopen}"
        )
